#? Arquivo gerado a partir de classes.json

classes = [{'abilities': [{'description': 'Um Acadêmico é capaz de lançar magias divinas '
                                'diariamente a partir do 1º nível. Para '
                                'prepará-las, o Acadêmico deve rezar para o '
                                'Panteão e pedir que magias lhe sejam '
                                'concedidas naquele dia, respeitando os seus '
                                'limites de nível e de sabedoria.',
                 'level': 1,
                 'name': 'Magias Divinas'},
                {'description': 'O Acadêmico é capaz de identificar monstros e '
                                'animais além de conhecer seus ataques e '
                                'defesas, habilidades e fraquezas, além dos '
                                'seus hábitos mais comuns com 1-2 chances em '
                                '1d6.',
                 'level': 1,
                 'name': 'Conhecimento Acadêmico'},
                {'description': 'Com seu conhecimento acadêmico, é capaz '
                                'também de decifrar linguagens, identificando '
                                'idiomas, alfabetos e pictogramas, decodificar '
                                'documentos e inscrições conhecendo ao menos a '
                                'ideia geral do texto. A chance de conseguir '
                                'usar a habilidade Conhecimento Acadêmico '
                                'evolui para 1-3 chances em 1d6.',
                 'level': 3,
                 'name': 'Decifrar Linguagens'},
                {'description': 'Com seu conhecimento acadêmico, é capaz '
                                'também de identificar lendas, tradições, '
                                'eventos, personalidades e vultos históricos, '
                                'além de curiosidades e perigos de lugares, '
                                'regiões e cidades. O Acadêmico conhece ainda '
                                'um rumor adicional sobre o lugar em questão '
                                'por modificador de sabedoria que possuir. A '
                                'chance de conseguir usar a habilidade '
                                'Conhecimento Acadêmico evolui para 1-4 '
                                'chances em 1d6.',
                 'level': 6,
                 'name': 'Lendas e Tradições'},
                {'description': 'Permite ao Acadêmico, ao observar '
                                'minuciosamente um item mágico por ao menos '
                                '1d4 turnos e com uma chance de 1-2 em 1d6, '
                                'identificar seus propósitos gerais (exemplo — '
                                'esta é uma espada encantada para ser usada '
                                'contra licantropos; ou ainda — estas botas '
                                'parecem ter sido costuradas por elfos) mesmo '
                                'que suas funções exatas não sejam reveladas.\n'
                                '\n'
                                'Itens mágicos caóticos se camuflam e não '
                                'podem ser reconhecidos desta maneira, sempre '
                                'forçando um reconhecimento errado do seu '
                                'propósito geral.',
                 'level': 10,
                 'name': 'Identificar itens'},
                {'description': 'O Acadêmico de alto nível atinge um grau '
                                'superior de reconhecimento pelos seus feitos, '
                                'obtendo Reputação 1 em 1d6. O valor de '
                                'Reputação evolui em 1 até o máximo de 1-5 em '
                                '1d6 no 15º nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Pode usar todas as armaduras.',
  'flavor': 'Um Acadêmico é um Clérigo especialista motivado pelo amplo desejo '
            'de conhecimento, reverenciando as ciências, estudos e o acúmulo '
            'de informações concedidas pelo deus Curioso.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 35},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'high_level_hp_bonus': 1,
  'hp': 8,
  'id': 'academico',
  'levels': {'1': {'ba': 1, 'jp': 5},
             '10': {'ba': 7, 'jp': 11, 'xp': 100000},
             '11': {'ba': 7, 'jp': 11, 'xp': 200000},
             '12': {'ba': 7, 'jp': 11, 'xp': 300000},
             '13': {'ba': 9, 'jp': 13, 'xp': 400000},
             '14': {'ba': 9, 'jp': 13, 'xp': 500000},
             '15': {'ba': 9, 'jp': 13, 'xp': 600000},
             '2': {'ba': 1, 'jp': 5, 'xp': 2000},
             '3': {'ba': 1, 'jp': 5, 'xp': 4000},
             '4': {'ba': 3, 'jp': 7, 'xp': 7000},
             '5': {'ba': 3, 'jp': 7, 'xp': 10000},
             '6': {'ba': 3, 'jp': 7, 'xp': 20000},
             '7': {'ba': 5, 'jp': 9, 'xp': 30000},
             '8': {'ba': 5, 'jp': 9, 'xp': 40000},
             '9': {'ba': 5, 'jp': 9, 'xp': 50000}},
  'magic_items_description': 'Pode usar qualquer item mágico.',
  'name': 'Acadêmico',
  'parent_class_url': 'https://olddragon.com.br/classes/clerigo.json',
  'picture': 'https://public.olddragon.com.br/vo55pidbzxakwluwd59r7p2w1qs1',
  'restrictions': {'alignments': ['neutro']},
  'thumb_picture': 'https://public.olddragon.com.br/lxpssl28s7yogb8z363ch4l2jm79',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/academico.json',
  'weapons_description': 'Só podem usar armas impactantes.'},
 {'abilities': [{'description': 'O Anão Aventureiro mantém todas as '
                                'habilidades raciais recebidas por ser um anão '
                                'e, devido ao intenso treinamento, atinge um '
                                'grau de especialização em machados ou '
                                'martelos, recebendo um bônus de +2 no dano da '
                                'arma escolhida. Esta arma passa a ser tratada '
                                'como sua arma racial.',
                 'level': 1,
                 'name': 'Arma Racial'},
                {'description': 'O Anão Aventureiro, deste nível em diante, '
                                'passa a jogar seus pontos de vida com 1d12 em '
                                'vez de 1d10 até o 10º nível. Adicionalmente, '
                                'o Anão Aventureiro pode optar por escolher o '
                                'valor médio do dado de vida (6) ao invés de '
                                'jogá-lo do 3º ao 10º nível.',
                 'level': 3,
                 'name': 'Duro na Queda'},
                {'description': 'O Anão Aventureiro intensifica seu '
                                'treinamento contra os principais inimigos da '
                                'sua raça – Orcs, Ogros e Hobgoblins – e, por '
                                'isso, os ataques destas criaturas contra um '
                                'Anão Aventureiro são considerados ataques '
                                'difíceis.',
                 'level': 6,
                 'name': 'Bastião Racial'},
                {'description': 'O Anão Aventureiro adquire um segundo ataque '
                                'com sua arma racial escolhida no 1º nível '
                                '(machado ou martelo).\n'
                                '\n'
                                'Este segundo ataque é realizado após o '
                                'primeiro ataque, logo em sequência, antes da '
                                'ação do próximo jogador na ordem da '
                                'iniciativa, com a mesma BA usada no primeiro '
                                'ataque.',
                 'level': 10,
                 'name': 'Ataque Extra'},
                {'description': 'O Anão Aventureiro de alto nível atinge um '
                                'grau superior de reconhecimento pelos seus '
                                'feitos, obtendo Reputação 1 em 1d6. O valor '
                                'de Reputação evolui em 1 até o máximo de 1-5 '
                                'em 1d6 no 15º nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Pode usar todas as armaduras.',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 22},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'high_level_hp_bonus': 2,
  'hp': 10,
  'id': 'anao-aventureiro',
  'levels': {'1': {'ba': 1, 'jp': 5},
             '10': {'ba': 10, 'jp': 11, 'xp': 106000},
             '11': {'ba': 11, 'jp': 13, 'xp': 210000},
             '12': {'ba': 12, 'jp': 13, 'xp': 320000},
             '13': {'ba': 13, 'jp': 14, 'xp': 430000},
             '14': {'ba': 14, 'jp': 14, 'xp': 540000},
             '15': {'ba': 15, 'jp': 16, 'xp': 650000},
             '2': {'ba': 2, 'jp': 5, 'xp': 2500},
             '3': {'ba': 3, 'jp': 6, 'xp': 5000},
             '4': {'ba': 4, 'jp': 6, 'xp': 8500},
             '5': {'ba': 5, 'jp': 8, 'xp': 11500},
             '6': {'ba': 6, 'jp': 8, 'xp': 23000},
             '7': {'ba': 7, 'jp': 10, 'xp': 33000},
             '8': {'ba': 8, 'jp': 10, 'xp': 43000},
             '9': {'ba': 9, 'jp': 11, 'xp': 53000}},
  'magic_items_description': 'Não pode usar cajados, varinhas e pergaminhos '
                             'mágicos com exceção dos pergaminhos de proteção.',
  'name': 'Anão Aventureiro',
  'parent_class_url': 'https://olddragon.com.br/classes/guerreiro.json',
  'picture': 'https://public.olddragon.com.br/nrjw08bg5frq0pls7cy3c6mq72oa',
  'restrictions': {'races': ['anao']},
  'thumb_picture': 'https://public.olddragon.com.br/lb830cnsrqv5sxc44jlaa8ba6xt0',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/anao-aventureiro.json',
  'weapons_description': 'Pode usar todas as armas.'},
 {'abilities': [{'description': 'Um Arqueiro pode, após receber um ataque '
                                'físico que o atinja e antes da jogada de dano '
                                'desse ataque, escolher sacrificar seu escudo '
                                'ou uma arma que esteja portando para absorver '
                                'todo o dano do ataque recebido.\n'
                                '\n'
                                'Armas e Escudos usados em um aparar ficarão '
                                'inutilizados e danificados. Armas e Escudos '
                                'mágicos possuem uma chance de 1-2 em 1d6 de '
                                'se danificarem, reduzindo seus bônus (de '
                                'ataque/ defesa) em 1 de modo que um escudo +3 '
                                'ao ser usado em um aparar, e se danificado, '
                                'passa ter como bônus de defesa +2 e assim '
                                'sucessivamente.\n'
                                '\n'
                                'Um item mágico que perder todos os bônus '
                                'estará permanentemente destruído. Apenas '
                                'ataques provenientes de inimigos grandes ou '
                                'menores poderão ser aparados.',
                 'level': 1,
                 'name': 'Aparar'},
                {'description': 'O Arqueiro se torna Mestre em uma arma à sua '
                                'escolha, recebendo um bônus de +1 no dano '
                                'daquela arma.',
                 'level': 1,
                 'name': 'Maestria de Armas'},
                {'description': 'O Arqueiro domina a técnica de usar flechas '
                                'desbalanceadas para realizar tiros em curva e '
                                'com parábolas perfeitas. Para ele, não são '
                                'considerados ataques difíceis: tiros contra '
                                'alvos com cobertura, alvos além da distância '
                                'permitida pelo arco e alvos engajados em '
                                'combate corpo a corpo.',
                 'level': 1,
                 'name': 'Tiros em Curva'},
                {'description': 'O Arqueiro consegue puxar seu arco acima das '
                                'capacidades consideradas normais, extraindo o '
                                'melhor de sua arma. O Arqueiro pode '
                                'acrescentar seu modificador de Força nos '
                                'danos do seu ataque com arcos.',
                 'level': 3,
                 'name': 'Puxada Aprimorada'},
                {'description': 'O Arqueiro é capaz de realizar truques com '
                                'seus disparos, podendo grampear alvos na '
                                'madeira macia, desarmá-los ou para realizar '
                                'outros efeitos como, por exemplo, modificar '
                                'uma flecha para que ela possa apitar ao se '
                                'deslocar no ar. O Arqueiro realiza um ataque '
                                'normal contra a CA + DV do alvo e, se for '
                                'bem-sucedido, o alvo deve decidir entre '
                                'sofrer as consequências do ataque com truque '
                                'ou receber o dano normalmente. O Mestre deve '
                                'ser consultado sobre os efeitos dos truques e '
                                'a possibilidade de realizá-los.',
                 'level': 6,
                 'name': 'Truques com Flechas'},
                {'description': 'O Arqueiro recebe neste nível a habilidade de '
                                'realizar um segundo disparo durante sua ação '
                                'de combate.',
                 'level': 10,
                 'name': 'Tiro Rápido'},
                {'description': 'O Arqueiro de alto nível atinge um grau '
                                'superior de reconhecimento pelos seus feitos, '
                                'obtendo Reputação 1 em 1d6. O valor de '
                                'Reputação evolui em 1 até o máximo de 1-5 em '
                                '1d6 no 15º nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Apenas armaduras de couro ou, caso contrário, não '
                        'conseguirá usar suas habilidades de arqueiro.',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 23},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'high_level_hp_bonus': 2,
  'hp': 10,
  'id': 'arqueiro',
  'levels': {'1': {'ba': 1, 'jp': 5},
             '10': {'ba': 10, 'jp': 11, 'xp': 106000},
             '11': {'ba': 11, 'jp': 13, 'xp': 210000},
             '12': {'ba': 12, 'jp': 13, 'xp': 320000},
             '13': {'ba': 13, 'jp': 14, 'xp': 430000},
             '14': {'ba': 14, 'jp': 14, 'xp': 540000},
             '15': {'ba': 15, 'jp': 16, 'xp': 650000},
             '2': {'ba': 2, 'jp': 5, 'xp': 2500},
             '3': {'ba': 3, 'jp': 6, 'xp': 5000},
             '4': {'ba': 4, 'jp': 6, 'xp': 8500},
             '5': {'ba': 5, 'jp': 8, 'xp': 11500},
             '6': {'ba': 6, 'jp': 8, 'xp': 23000},
             '7': {'ba': 7, 'jp': 10, 'xp': 33000},
             '8': {'ba': 8, 'jp': 10, 'xp': 43000},
             '9': {'ba': 9, 'jp': 11, 'xp': 53000}},
  'magic_items_description': 'Não pode usar cajados, varinhas e pergaminhos '
                             'mágicos com exceção dos pergaminhos de proteção.',
  'name': 'Arqueiro',
  'parent_class_url': 'https://olddragon.com.br/classes/guerreiro.json',
  'picture': 'https://public.olddragon.com.br/ij3w418akaqh5hla1dzg3u1fq63h',
  'restrictions': {},
  'thumb_picture': 'https://public.olddragon.com.br/87x2p1k79v36gd2oyrdoi8hn61cn',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/arqueiro.json',
  'weapons_description': 'Apenas armas pequenas, porém pode utilizar qualquer '
                         'tipo de arco.'},
 {'abilities': [{'description': 'Assassinos possuem algumas habilidades as '
                                'quais representam seus principais campos de '
                                'atuação, começando com 2 pontos em cada um '
                                'dos cinco talentos e 2 pontos adicionais para '
                                'distribuir como desejar.',
                 'level': 1,
                 'level10': 'Recebe 2 pontos para evoluir seus talentos.',
                 'level3': 'Recebe 2 pontos para evoluir seus talentos.',
                 'level6': 'Recebe 2 pontos para evoluir seus talentos.',
                 'name': 'Talentos de Ladrão'},
                {'description': 'Ao atacar após ter se aproximado do inimigo '
                                'furtivamente, o Assassino é capaz de realizar '
                                'um ataque muito fácil, causando dano '
                                'multiplicado por 2.',
                 'level': 1,
                 'name': 'Ataque Assassino'},
                {'description': 'O Assassino que passa uma rodada completa sem '
                                'agir, apenas observando os movimentos do seu '
                                'alvo e reconhecendo os pontos fracos deste, '
                                'transforma o seu primeiro ataque contra este '
                                'alvo em um ataque fácil. Se o Assassino '
                                'passar 4 rodadas completas observando-o, o '
                                'ataque passa a ser muito fácil.',
                 'level': 3,
                 'name': 'Espreitar'},
                {'description': 'Ao desferir um _Ataque Assassino_, abre mão '
                                'do ataque normal para tentar um golpe fatal, '
                                'matando imediatamente o alvo. A chance do '
                                'golpe ser bem-sucedido é de 1-2 em 1d6. No '
                                '10º nível, a chance evolui para 1-3 em 1d6. '
                                'Cada DV do alvo, igual ou acima do DV do '
                                'Assassino, reduz a chance básica em 1 em 1d6. '
                                'Caso o _Assassinato_ falhe, o alvo não recebe '
                                'dano e fica imune a um novo Assassinato até o '
                                'Assassino evoluir para o próximo nível.',
                 'level': 6,
                 'name': 'Assassinato'},
                {'description': 'O Assassino evolui seu _Ataque Assassino_, '
                                'causando dano multiplicado por 3.',
                 'level': 10,
                 'name': 'Ataque Mortal'},
                {'description': 'O Assassino de alto nível atinge um grau '
                                'superior de reconhecimento pelos seus feitos, '
                                'obtendo Reputação 1 em 1d6. O valor de '
                                'Reputação evolui em 1 até o máximo de 1-5 em '
                                '1d6 no 15º nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Apenas as leves. Escudos, Armaduras Média ou Pesadas, '
                        'impedem o uso das suas habilidades e protegem apenas '
                        'a metade da CA normal.',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 30},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'high_level_hp_bonus': 1,
  'hp': 6,
  'id': 'assassino',
  'levels': {'1': {'ba': 1, 'jp': 5},
             '10': {'ba': 5, 'jp': 11, 'xp': 94000},
             '11': {'ba': 6, 'jp': 11, 'xp': 190000},
             '12': {'ba': 6, 'jp': 11, 'xp': 280000},
             '13': {'ba': 7, 'jp': 14, 'xp': 370000},
             '14': {'ba': 7, 'jp': 14, 'xp': 460000},
             '15': {'ba': 8, 'jp': 14, 'xp': 550000},
             '2': {'ba': 1, 'jp': 5, 'xp': 1500},
             '3': {'ba': 2, 'jp': 5, 'xp': 3000},
             '4': {'ba': 2, 'jp': 5, 'xp': 5500},
             '5': {'ba': 3, 'jp': 8, 'xp': 8500},
             '6': {'ba': 3, 'jp': 8, 'xp': 17000},
             '7': {'ba': 4, 'jp': 8, 'xp': 27000},
             '8': {'ba': 4, 'jp': 8, 'xp': 37000},
             '9': {'ba': 5, 'jp': 11, 'xp': 47000}},
  'magic_items_description': 'Não pode usar cajados, varinhas e pergaminhos '
                             'mágicos com exceção dos pergaminhos de proteção.',
  'name': 'Assassino',
  'parent_class_url': 'https://olddragon.com.br/classes/ladrao.json',
  'picture': 'https://public.olddragon.com.br/6eb1niau1kiybuer9pqtl0oieiqm',
  'restrictions': {},
  'thumb_picture': 'https://public.olddragon.com.br/tiacugh76np83ff893pkbxdlurnu',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/assassino.json',
  'weapons_description': 'Apenas pequenas ou médias. Armas grandes geram '
                         'ataques difíceis para o Assassino.'},
 {'abilities': [{'description': 'Um Bárbaro pode, após receber um ataque '
                                'físico que o atinja e antes da jogada de dano '
                                'desse ataque, escolher sacrificar seu escudo '
                                'ou uma arma que esteja portando para absorver '
                                'todo o dano do ataque recebido.\n'
                                '\n'
                                'Armas e Escudos usados em um aparar ficarão '
                                'inutilizados e danificados. Armas e Escudos '
                                'mágicos possuem uma chance de 1-2 em 1d6 de '
                                'se danificarem, reduzindo seus bônus (de '
                                'ataque/ defesa) em 1 de modo que um escudo +3 '
                                'ao ser usado em um aparar, e se danificado, '
                                'passa ter como bônus de defesa +2 e assim '
                                'sucessivamente.\n'
                                '\n'
                                'Um item mágico que perder todos os bônus '
                                'estará permanentemente destruído. Apenas '
                                'ataques provenientes de inimigos grandes ou '
                                'menores poderão ser aparados.',
                 'level': 1,
                 'name': 'Aparar'},
                {'description': 'O Bárbaro se torna Mestre em uma arma à sua '
                                'escolha, recebendo um bônus de +1 no dano '
                                'daquela arma.',
                 'level': 1,
                 'name': 'Maestria em Arma'},
                {'description': 'A cada nível, o Bárbaro recebe um Bônus de +2 '
                                'nos seus pontos de vida adicionais à tabela '
                                'de Guerreiro e um bônus de +2 na sua JPC.',
                 'level': 1,
                 'name': 'Vigor Bárbaro'},
                {'description': 'O Bárbaro adquire alguns talentos ligados à '
                                'sua vida nos ermos selvagens:\n'
                                '\n'
                                '* **Escalar** escalam como Ladrões qualquer '
                                'superfície natural como árvores, barrancos, '
                                'encostas rochosas, escorregadias ou não, com '
                                '1-3 chances em 1d6. Em caso de falha, '
                                'Bárbaros caem da metade da altura total da '
                                'escalada, recebendo 1d6 pontos de dano para '
                                'cada 3 metros da queda.\n'
                                '* **Camuflagem Natural** em ambientes '
                                'naturais, como vegetação rasteira ou árvores '
                                'com uma chance de 1-2 em 1d6. O mestre deve '
                                'lançar os dados em segredo para que o Bárbaro '
                                'não saiba se sua tentativa de camuflagem foi '
                                'bem-sucedida ou não.',
                 'level': 3,
                 'name': 'Talentos Selvagens'},
                {'description': 'O Bárbaro é capaz de surpreender seus '
                                'inimigos em ambientes naturais com uma chance '
                                'de 1-4 em 1d6, mesmo quando em tocaia com '
                                'aliados não Bárbaros.\n'
                                '\n'
                                'Além disso, um Bárbaro só é surpreendido em '
                                'ambientes naturais com uma chance de 1 em '
                                '1d6.',
                 'level': 6,
                 'name': 'Surpresa Selvagem'},
                {'description': 'O Bárbaro é capaz de atingir qualquer '
                                'criatura que necessite de uma arma mágica +1 '
                                'ou melhor para ser ferida.',
                 'level': 10,
                 'name': 'Força do Totem'},
                {'description': 'O Bárbaro de alto nível atinge um grau '
                                'superior de reconhecimento pelos seus feitos, '
                                'obtendo Reputação 1 em 1d6. O valor de '
                                'Reputação evolui em 1 até o máximo de 1-5 em '
                                '1d6 no 15º nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Apenas armaduras de couro, ou perderá acesso a todas '
                        'as suas habilidades de Bárbaro.',
  'flavor': 'Bárbaros são Guerreiros nascidos em culturas remotas de regiões '
            'distantes e rústicas, em comunhão com a terra.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 30},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'high_level_hp_bonus': 2,
  'hp': 10,
  'id': 'barbaro',
  'levels': {'1': {'ba': 1, 'jp': 5},
             '10': {'ba': 10, 'jp': 11, 'xp': 106000},
             '11': {'ba': 11, 'jp': 13, 'xp': 210000},
             '12': {'ba': 12, 'jp': 13, 'xp': 320000},
             '13': {'ba': 13, 'jp': 14, 'xp': 430000},
             '14': {'ba': 14, 'jp': 14, 'xp': 540000},
             '15': {'ba': 15, 'jp': 16, 'xp': 650000},
             '2': {'ba': 2, 'jp': 5, 'xp': 2500},
             '3': {'ba': 3, 'jp': 6, 'xp': 5000},
             '4': {'ba': 4, 'jp': 6, 'xp': 8500},
             '5': {'ba': 5, 'jp': 8, 'xp': 11500},
             '6': {'ba': 6, 'jp': 8, 'xp': 23000},
             '7': {'ba': 7, 'jp': 10, 'xp': 33000},
             '8': {'ba': 8, 'jp': 10, 'xp': 43000},
             '9': {'ba': 9, 'jp': 11, 'xp': 53000}},
  'magic_items_description': 'Não pode usar nenhum item mágico, ou perderá '
                             'acesso a todas as suas habilidades de Bárbaro.',
  'name': 'Bárbaro',
  'parent_class_url': 'https://olddragon.com.br/classes/guerreiro.json',
  'picture': 'https://public.olddragon.com.br/0gi3xu5ya8rh5nw72bckj76prnkm',
  'restrictions': {},
  'thumb_picture': 'https://public.olddragon.com.br/euse73abs6pzh1xl317ngcrg7fdp',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/barbaro.json',
  'weapons_description': 'Pode usar todas as armas.'},
 {'access': 'limited',
  'flavor': 'Guerreiro das terras selvagens, resistente, instintivo e guiado '
            'por códigos ancestrais de honra.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 60}],
  'id': 'barbaro-sdg',
  'name': 'Bárbaro (Senhores da Guerra)',
  'parent_class_url': 'https://olddragon.com.br/classes/guerreiro.json',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/barbaro-sdg.json'},
 {'abilities': [{'description': 'O Bardo consegue ouvir ruídos como uma '
                                'conversa do outro lado de uma porta ou sons '
                                'de monstros se aproximando. Para isso, ele '
                                'deve estar em um ambiente silencioso, como em '
                                'uma masmorra e fora de um combate.\n'
                                '\n'
                                'O Bardo possui uma chance de 1-2 em 1d6 para '
                                'conseguir ouvir ruídos.',
                 'level': 1,
                 'level10': 'A chance aumenta para 1-5 em 1d6.',
                 'level3': 'A chance aumenta para 1-3 em 1d6.',
                 'level6': 'A chance aumenta para 1-4 em 1d6.',
                 'name': 'Ouvir Ruídos'},
                {'description': 'Bardos possuem algumas habilidades as quais '
                                'representam seus principais campos de '
                                'atuação, começando com 2 pontos em cada um '
                                'dos cinco talentos e 2 pontos adicionais para '
                                'distribuir como desejar.',
                 'level': 1,
                 'level10': 'Recebe 2 pontos para evoluir seus talentos.',
                 'level3': 'Recebe 2 pontos para evoluir seus talentos.',
                 'level6': 'Recebe 2 pontos para evoluir seus talentos.',
                 'name': 'Talentos de Ladrão'},
                {'description': 'O Bardo por meio da música, oratórias e '
                                'baladas heroicas consegue influenciar as '
                                'reações de monstros ou personagens do Mestre '
                                'com uma chance de 1-2 em 1d6. O Bardo recebe '
                                'um modificador de +1 ou -1 no Teste de Reação '
                                'destas audiências para melhorar a reação dos '
                                'alvos (+1) ou para torná-los mais hostis '
                                '(-1).',
                 'level': 1,
                 'name': 'Influenciar'},
                {'description': 'O Bardo se for capaz de passar ao menos uma '
                                'rodada atuando, e enquanto continuar mantendo '
                                'a atuação, consegue que seus aliados se '
                                'tornem mais confiantes no sucesso. Um alvo '
                                'inspirado pelo Bardo faz com que seus testes '
                                'de atributos e ataques fiquem como se fossem '
                                'um nível mais fácil do que realmente são, '
                                'tornando, por exemplo, testes muito difíceis '
                                'em apenas testes difíceis.',
                 'level': 3,
                 'name': 'Inspirar'},
                {'description': 'O Bardo por meio da música, oratória e '
                                'baladas heroicas consegue deixar uma '
                                'audiência de monstros ou personagens do '
                                'Mestre não hostis, que tenham até 2 Dados de '
                                'vida a cada 3 níveis do Bardo, desde que '
                                'entenda o idioma usado pelo Bardo, envolvida '
                                'e concentrada no seu desempenho artístico.',
                 'level': 6,
                 'name': 'Fascinar'},
                {'description': 'O Bardo adquire a habilidade de Usar '
                                'Pergaminhos como se fosse um Mago com metade '
                                'dos níveis que possuir.',
                 'level': 10,
                 'name': 'Usar Pergaminhos'},
                {'description': 'O Bardo de alto nível atinge um grau superior '
                                'de reconhecimento pelos seus feitos, obtendo '
                                'Reputação 1 em 1d6. O valor de Reputação '
                                'evolui em 1 até o máximo de 1-5 em 1d6 no 15º '
                                'nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Apenas as leves. Escudos, Armaduras Média ou Pesadas, '
                        'impedem o uso das suas habilidades e protegem apenas '
                        'a metade da CA normal.',
  'flavor': 'O Bardo é um personagem ligado às artes e à performance. São '
            'viajantes, repórteres da vida cotidiana e divulgadores de feitos '
            'épicos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 41},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'high_level_hp_bonus': 1,
  'hp': 6,
  'id': 'bardo',
  'levels': {'1': {'ba': 1, 'jp': 5},
             '10': {'ba': 5, 'jp': 11, 'xp': 94000},
             '11': {'ba': 6, 'jp': 11, 'xp': 190000},
             '12': {'ba': 6, 'jp': 11, 'xp': 280000},
             '13': {'ba': 7, 'jp': 14, 'xp': 370000},
             '14': {'ba': 7, 'jp': 14, 'xp': 460000},
             '15': {'ba': 8, 'jp': 14, 'xp': 550000},
             '2': {'ba': 1, 'jp': 5, 'xp': 1500},
             '3': {'ba': 2, 'jp': 5, 'xp': 3000},
             '4': {'ba': 2, 'jp': 5, 'xp': 5500},
             '5': {'ba': 3, 'jp': 8, 'xp': 8500},
             '6': {'ba': 3, 'jp': 8, 'xp': 17000},
             '7': {'ba': 4, 'jp': 8, 'xp': 27000},
             '8': {'ba': 4, 'jp': 8, 'xp': 37000},
             '9': {'ba': 5, 'jp': 11, 'xp': 47000}},
  'magic_items_description': 'Podem usar todos os pergaminhos mágicos com '
                             'metade dos níveis que possuir.',
  'name': 'Bardo',
  'parent_class_url': 'https://olddragon.com.br/classes/ladrao.json',
  'picture': 'https://public.olddragon.com.br/bcyaeu2xhk0z0vn3fvkpauwh5sfb',
  'restrictions': {},
  'thumb_picture': 'https://public.olddragon.com.br/b6evi44n8tq8wbxgprxlkm1s1ftq',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/bardo.json',
  'weapons_description': 'Apenas pequenas ou médias. Armas grandes geram '
                         'ataques difíceis para o Bardo.'},
 {'access': 'limited',
  'flavor': 'Cronista das guerras, viajante astuto e aprendiz das tradições '
            'orais e mágicas da velha fé.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 60}],
  'id': 'bardo-sdg',
  'name': 'Bardo (Senhores da Guerra)',
  'parent_class_url': 'https://olddragon.com.br/classes/ladrao.json',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/bardo-sdg.json'},
 {'access': 'limited',
  'flavor': 'Espião, batedor e assassino do exército, treinado para agir antes '
            'que a batalha comece.\n',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 59}],
  'id': 'batedor-sdg',
  'name': 'Batedor (Senhores da Guerra)',
  'parent_class_url': 'https://olddragon.com.br/classes/ladrao.json',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/batedor-sdg.json'},
 {'abilities': [{'description': 'O Bruxo se concentra no efeito desejado '
                                'iniciando um pequeno ritual de palavras e '
                                'gestos que canalizam o poder extraplanar no '
                                'seu corpo, realizando o efeito da magia.\n'
                                '\n'
                                '- **Metal**: Objetos de metal como armas, '
                                'armaduras, escudos etc. atrapalham a '
                                'canalização do ritual, impedindo a conjuração '
                                'das magias. Se estiver em contato com objetos '
                                'de metal, o Bruxo possui 1-2 chances em 1d6 '
                                'de perder o ritual sem que qualquer efeito '
                                'ocorra.\n'
                                '- **Execução**: Um ritual leva uma rodada '
                                'para ser executado. Uma magia conjurada nesta '
                                'rodada iniciará seus efeitos no início da '
                                'próxima rodada, antes das outras ações.\n'
                                '- **Lista de Rituais**: O Bruxo pode escolher '
                                'livremente suas magias dentre todas as magias '
                                'dos círculos disponíveis para seu nível, como '
                                'se estivessem escritas no seu grimório.\n'
                                '- **Rituais Extras**: O Bruxo não recebe '
                                'magias adicionais por um alto valor de '
                                'Inteligência.',
                 'level': 1,
                 'name': 'Rituais'},
                {'description': 'O Bruxo consegue conjurar magias de 1º '
                                'círculo e pode usar armas médias e armaduras '
                                'leves, mesmo as de metal, sem prejudicar seus '
                                'rituais.',
                 'level': 1,
                 'name': 'Iniciado'},
                {'description': 'O Bruxo consegue conjurar magias de 2º '
                                'círculo e pode usar armas grandes, mesmo as '
                                'de metal, sem prejudicar seus rituais.',
                 'level': 3,
                 'name': 'Médium'},
                {'description': 'O Bruxo consegue conjurar magias de 3º '
                                'círculo e pode usar armaduras médias, mesmo '
                                'as de metal, sem prejudicar seus rituais.',
                 'level': 6,
                 'name': 'Conjurador'},
                {'description': 'O Bruxo consegue conjurar magias de 4º, 5º e '
                                '6º círculos, desde que seu nível permita '
                                'acesso a estes círculos, e pode usar todas as '
                                'armaduras ou armas, mesmo as de metal, sem '
                                'prejudicar seus rituais.',
                 'level': 10,
                 'name': 'Entidade'},
                {'description': 'Um Bruxo é capaz de uma vez ao dia por nível '
                                'decifrar e ler inscrições mágicas em qualquer '
                                'lugar, mesmo que não entenda a mensagem a '
                                'qual elas querem passar.\n'
                                '\n'
                                'Esta habilidade não permite identificar as '
                                'propriedades mágicas de um item mágico, nem é '
                                'necessária para lançar magias escritas, mas '
                                'permitirá identificar qual magia está escrita '
                                'ali.',
                 'level': 1,
                 'name': 'Ler Magias'},
                {'description': 'Um Bruxo é capaz de uma vez ao dia por nível '
                                'perceber em lugares, pessoas ou coisas em uma '
                                'área de até 9m + 3m por nível, a presença de '
                                'magia, desde que esteja concentrado e '
                                'procurando ativamente por isso.\n'
                                '\n'
                                'O Bruxo percebe uma tênue aura mágica ao '
                                'redor dos lugares, pessoas ou coisas '
                                'encantadas, mas não é capaz de identificar a '
                                'magia, o nível de poder do conjurador ou o '
                                'efeito presente no alvo.\n'
                                '\n'
                                'Um Bruxo precisa se concentrar 1d8 rodadas na '
                                'área desejada para conseguir detectar, caso '
                                'haja, alguma presença mágica. Esse tempo cai '
                                'para 1d4 rodadas no 6º nível e para 1 rodada '
                                'no 10º nível.',
                 'level': 1,
                 'name': 'Detectar Magias'},
                {'description': 'O Bruxo de alto nível atinge um grau superior '
                                'de reconhecimento pelos seus feitos, obtendo '
                                'Reputação 1 em 1d6. O valor de Reputação '
                                'evolui em 1 até o máximo de 1-5 em 1d6 no 15º '
                                'nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Nenhuma. Usar escudos ou armaduras impede a '
                        'conjuração de magias e protegem apenas metade da CA '
                        'normal.',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 34},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'high_level_hp_bonus': 1,
  'hp': 4,
  'id': 'bruxo',
  'levels': {'1': {'ba': 0, 'jp': 5},
             '10': {'ba': 3, 'jp': 10, 'xp': 112000},
             '11': {'ba': 4, 'jp': 10, 'xp': 220000},
             '12': {'ba': 4, 'jp': 10, 'xp': 340000},
             '13': {'ba': 4, 'jp': 10, 'xp': 460000},
             '14': {'ba': 5, 'jp': 13, 'xp': 580000},
             '15': {'ba': 5, 'jp': 13, 'xp': 700000},
             '2': {'ba': 1, 'jp': 5, 'xp': 3000},
             '3': {'ba': 1, 'jp': 5, 'xp': 6000},
             '4': {'ba': 1, 'jp': 5, 'xp': 10000},
             '5': {'ba': 2, 'jp': 7, 'xp': 13000},
             '6': {'ba': 2, 'jp': 7, 'xp': 26000},
             '7': {'ba': 2, 'jp': 7, 'xp': 36000},
             '8': {'ba': 3, 'jp': 7, 'xp': 46000},
             '9': {'ba': 3, 'jp': 7, 'xp': 56000}},
  'magic_items_description': 'Podem usar todos os tipos.',
  'name': 'Bruxo',
  'parent_class_url': 'https://olddragon.com.br/classes/mago.json',
  'picture': 'https://public.olddragon.com.br/mauhhtgxm41pea9jcso48vvm59am',
  'restrictions': {},
  'thumb_picture': 'https://public.olddragon.com.br/9ksutoj5s8y2zt4sjy5ccpszssvv',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/bruxo.json',
  'weapons_description': 'Apenas pequenas. Armas grandes ou médias geram '
                         'ataques difíceis para Bruxos.'},
 {'abilities': [{'description': 'Um Clérigo é capaz de lançar magias divinas '
                                'diariamente a partir do 1º nível. Para '
                                'prepará-las, o Clérigo deve rezar para o '
                                'Panteão e pedir que magias lhe sejam '
                                'concedidas naquele dia, respeitando os seus '
                                'limites de nível e de sabedoria.',
                 'level': 1,
                 'name': 'Magias Divinas'},
                {'description': 'O Clérigo é capaz de invocar o nome e o poder '
                                'de sua divindade brandindo seu símbolo '
                                'sagrado, fazendo os mortos-vivos a até 18 '
                                'metros e que não passem em um teste de moral '
                                'no final da rodada, se contorcerem e tentarem '
                                'a todo custo fugir do Clérigo.\n'
                                '\n'
                                '**Reduzir a Pó**: Se o morto-vivo não passar '
                                'no Teste de Moral e o resultado dos dados for '
                                'igual (tirando dois 4 nos dados, ou dois 5, '
                                'ou ainda dois 6) o morto-vivo não é apenas '
                                'afastado, mas também destruído e reduzido a '
                                'pó.\n'
                                '\n'
                                '**Alvo**: Todos os mortos-vivos num raio de '
                                'até 18 metros do Clérigo são afetados pelo '
                                'Afastar Mortos-vivos. Mortos-vivos '
                                'bem-sucedidos no teste de moral no final da '
                                'rodada ficam imunes a um novo Afastar '
                                'Mortos-vivos proferidos por este Clérigo, até '
                                'este adquirir um novo nível.',
                 'level': 1,
                 'level10': 'O Clérigo recebe um bônus de +2 nos seus testes '
                            'de Afastar Mortos-Vivos e pode tentar Afastar '
                            'Mortos-Vivos três vezes ao dia.',
                 'level3': 'O Clérigo recebe um bônus de +1 nos seus testes de '
                           'Afastar Mortos-Vivos e pode tentar Afastar '
                           'Mortos-Vivos duas vezes ao dia.',
                 'name': 'Afastar Mortos-Vivos'},
                {'description': 'Clérigos podem trocar uma magia previamente '
                                'memorizada por uma magia de Curar Ferimentos '
                                'de 1º círculo.',
                 'level': 1,
                 'level10': 'O Clérigo evolui seu poder de Cura, podendo '
                            'trocar uma magia memorizada por Curar Ferimentos '
                            'de 5º círculo, que cura até 3d8 pontos de vida.',
                 'level6': 'O Clérigo evolui seu poder de Cura, podendo trocar '
                           'uma magia memorizada por Curar Ferimentos de 3º '
                           'círculo, que cura até 2d8 pontos de vida.',
                 'name': 'Cura Milagrosa'},
                {'description': 'O Clérigo de alto nível atinge um grau '
                                'superior de reconhecimento pelos seus feitos, '
                                'obtendo Reputação 1 em 1d6. O valor de '
                                'Reputação evolui em 1 até o máximo de 1-5 em '
                                '1d6 no 15º nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Podem usar todas as armaduras.',
  'flavor': 'Aventureiro religioso e devoto das forças divinas do panteão.\n'
            'Determinado e virtuoso, protege a todos usando seus milagres '
            'divinos.\n',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 32},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'high_level_hp_bonus': 1,
  'hp': 8,
  'id': 'clerigo',
  'levels': {'1': {'ba': 1, 'jp': 5},
             '10': {'ba': 7, 'jp': 11, 'xp': 94000},
             '11': {'ba': 7, 'jp': 11, 'xp': 190000},
             '12': {'ba': 7, 'jp': 11, 'xp': 280000},
             '13': {'ba': 9, 'jp': 13, 'xp': 370000},
             '14': {'ba': 9, 'jp': 13, 'xp': 460000},
             '15': {'ba': 9, 'jp': 13, 'xp': 550000},
             '2': {'ba': 1, 'jp': 5, 'xp': 1500},
             '3': {'ba': 1, 'jp': 5, 'xp': 3000},
             '4': {'ba': 3, 'jp': 7, 'xp': 5500},
             '5': {'ba': 3, 'jp': 7, 'xp': 8500},
             '6': {'ba': 3, 'jp': 7, 'xp': 17000},
             '7': {'ba': 5, 'jp': 9, 'xp': 27000},
             '8': {'ba': 5, 'jp': 9, 'xp': 37000},
             '9': {'ba': 5, 'jp': 9, 'xp': 47000}},
  'magic_items_description': 'O Clérigo é capaz de usar todos os tipos de '
                             'itens mágicos desde que sejam ordeiros.',
  'name': 'Clérigo',
  'picture': 'https://public.olddragon.com.br/n7pq3ozcj3bwkepuvenwx7tdmwe2',
  'restrictions': {},
  'thumb_picture': 'https://public.olddragon.com.br/otp1flrbgmkghb5vs8svhnutccky',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/clerigo.json',
  'weapons_description': 'Só podem usar armas impactantes. Usar armas '
                         'cortantes ou perfurantes faz o Clérigo perder suas '
                         'magias até realizar uma penitência para restaurar o '
                         'abalo na sua fé.'},
 {'abilities': [{'description': 'Um Druida é capaz de lançar magias divinas '
                                'diariamente a partir do 1º nível. Para '
                                'prepará-las, o Druida deve rezar para o '
                                'Panteão e pedir que magias lhe sejam '
                                'concedidas naquele dia, respeitando os seus '
                                'limites de nível e de sabedoria.',
                 'level': 1,
                 'name': 'Magias Divinas'},
                {'description': 'O Druida adquire a habilidade de Herbalismo '
                                'sendo capaz de identificar plantas, animais e '
                                'reconhecer água pura e segura para o consumo.',
                 'level': 1,
                 'name': 'Herbalismo'},
                {'description': 'O Druida adquire a habilidade da Previdência '
                                'nos acampamentos os quais monta. Acampamentos '
                                'criados nos ermos por um Druida sempre serão '
                                'do tipo seguro.',
                 'level': 3,
                 'name': 'Previdência'},
                {'description': 'O Druida pode Assumir a Forma de um animal '
                                'pequeno não-mágico até 3 vezes ao dia.',
                 'level': 6,
                 'level10': 'O Druida evolui sua capacidade de Assumir a Forma '
                            'de animais até 3 vezes ao dia, podendo assumir a '
                            'forma de um animal não-mágico de qualquer tamanho '
                            'com até 10 DV.\n'
                            '\n'
                            'O Druida pode adotar todas as habilidades '
                            'especiais deste animal como, por exemplo, o '
                            'abraço de um Urso, mas mantém todas as suas '
                            'próprias estatísticas como bônus de ataque, '
                            'Jogadas de Proteção, classe de armadura e pontos '
                            'de vida.',
                 'level6': 'O Druida pode Assumir a Forma de um animal pequeno '
                           'não-mágico de até 6 DV por até 3 vezes ao dia.\n'
                           '\n'
                           'O Druida pode adotar uma habilidade especial deste '
                           'animal como, por exemplo, o abraço de um Urso, mas '
                           'mantém todas as suas próprias estatísticas como '
                           'bônus de ataque, Jogadas de Proteção, classe de '
                           'armadura e pontos de vida.',
                 'name': 'Transformação'},
                {'description': 'O Druida de alto nível atinge um grau '
                                'superior de reconhecimento pelos seus feitos, '
                                'obtendo Reputação 1 em 1d6. O valor de '
                                'Reputação evolui em 1 até o máximo de 1-5 em '
                                '1d6 no 15º nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Não pode usar nenhuma armadura metálica.',
  'flavor': 'Um Druida é um Clérigo especialista silvestre, tendo como sua '
            'divindade a Deusa-Mãe da natureza e as forças dela além do neutro '
            'equilíbrio da roda da vida.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 34},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'high_level_hp_bonus': 1,
  'hp': 8,
  'id': 'druida',
  'levels': {'1': {'ba': 1, 'jp': 5},
             '10': {'ba': 7, 'jp': 11, 'xp': 100000},
             '11': {'ba': 7, 'jp': 11, 'xp': 200000},
             '12': {'ba': 7, 'jp': 11, 'xp': 300000},
             '13': {'ba': 9, 'jp': 13, 'xp': 400000},
             '14': {'ba': 9, 'jp': 13, 'xp': 500000},
             '15': {'ba': 9, 'jp': 13, 'xp': 600000},
             '2': {'ba': 1, 'jp': 5, 'xp': 2000},
             '3': {'ba': 1, 'jp': 5, 'xp': 4000},
             '4': {'ba': 3, 'jp': 7, 'xp': 7000},
             '5': {'ba': 3, 'jp': 7, 'xp': 10000},
             '6': {'ba': 3, 'jp': 7, 'xp': 20000},
             '7': {'ba': 5, 'jp': 9, 'xp': 30000},
             '8': {'ba': 5, 'jp': 9, 'xp': 40000},
             '9': {'ba': 5, 'jp': 9, 'xp': 50000}},
  'magic_items_description': 'Pode usar qualquer item mágico.',
  'name': 'Druida',
  'parent_class_url': 'https://olddragon.com.br/classes/clerigo.json',
  'picture': 'https://public.olddragon.com.br/5yjngccfbcnaooepjlvktn8dlmja',
  'restrictions': {'alignments': ['neutro']},
  'thumb_picture': 'https://public.olddragon.com.br/mhqhk88bn2nwi6v399mpgb4tivx7',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/druida.json',
  'weapons_description': 'Não pode usar nenhuma arma metálica.'},
 {'access': 'limited',
  'flavor': 'Arauto dos deuses antigos, feiticeiro tribal e temido conselheiro '
            'de reis.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 61}],
  'id': 'druida-ancestral-sdg',
  'name': 'Druida Ancestral (Senhores da Guerra)',
  'parent_class_url': 'https://olddragon.com.br/classes/mago.json',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/druida-ancestral-sdg.json'},
 {'abilities': [{'description': 'O Elfo Aventureiro mantém todas as '
                                'habilidades raciais recebidas por ser um elfo '
                                'e, devido ao intenso treinamento marcial, '
                                'recebe a cada nível um bônus de +1 nos seus '
                                'pontos de vida adicionais à tabela de Mago.\n'
                                'Além disso, deixam de possuir restrições '
                                'quanto ao uso de armas ou armaduras como um '
                                'Mago.\n'
                                '\n'
                                'Seu treinamento nas suas armas raciais, '
                                'cimitarras ou arcos concedem a eles um bônus '
                                'de +2 no dano da arma escolhida. Esta arma '
                                'passa a ser tratada como sua arma racial.',
                 'level': 1,
                 'name': 'Treinamento Racial'},
                {'description': 'O Elfo Aventureiro começa a dominar as artes '
                                'arcanas na prática, sendo capaz de conjurar '
                                'uma única magia de 1º círculo por dia, como '
                                'um Mago de 1º nível.\n'
                                'Todas as regras de conjuração, uso de '
                                'armaduras, memorização, lista de magias e '
                                'grimório de um Mago são compartilhadas por um '
                                'Elfo Aventureiro.\n'
                                'Se estiver usando um escudo ou armadura, um '
                                'Elfo Aventureiro possui 1-3 chances em 1d6 de '
                                'perder a magia sem que qualquer efeito '
                                'ocorra.',
                 'level': 3,
                 'name': 'Brilho Mágico'},
                {'description': 'Elfo Aventureiro passa a ser capaz de lançar '
                                'magias arcanas diariamente como um Mago cinco '
                                'níveis abaixo do seu. Um Elfo Aventureiro de '
                                '6º nível memoriza e lança magias como um Mago '
                                'de 1º nível. Se estiver usando um escudo ou '
                                'armadura, um Elfo Aventureiro possui 1-2 '
                                'chances em 1d6 de perder a magia sem que '
                                'qualquer efeito ocorra.',
                 'level': 6,
                 'name': 'Esplendor Arcano'},
                {'description': 'O Elfo Aventureiro adquire um segundo ataque '
                                'com sua arma racial escolhida no 1º nível '
                                '(cimitarra ou arco). Este segundo ataque é '
                                'realizado após o primeiro ataque, logo em '
                                'sequência, antes da ação do próximo jogador '
                                'na ordem da iniciativa com a mesma BA usada '
                                'no primeiro ataque.',
                 'level': 10,
                 'name': 'Ataque Extra'},
                {'description': 'O Elfo Aventureiro de alto nível atinge um '
                                'grau superior de reconhecimento pelos seus '
                                'feitos, obtendo Reputação 1 em 1d6. O valor '
                                'de Reputação evolui em 1 até o máximo de 1-5 '
                                'em 1d6 no 15º nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Podem usar todas armaduras.',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 35},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'high_level_hp_bonus': 1,
  'hp': 4,
  'id': 'elfo-aventureiro',
  'levels': {'1': {'ba': 0, 'jp': 5},
             '10': {'ba': 3, 'jp': 10, 'xp': 112000},
             '11': {'ba': 4, 'jp': 10, 'xp': 220000},
             '12': {'ba': 4, 'jp': 10, 'xp': 340000},
             '13': {'ba': 4, 'jp': 10, 'xp': 460000},
             '14': {'ba': 5, 'jp': 13, 'xp': 580000},
             '15': {'ba': 5, 'jp': 13, 'xp': 700000},
             '2': {'ba': 1, 'jp': 5, 'xp': 3000},
             '3': {'ba': 1, 'jp': 5, 'xp': 6000},
             '4': {'ba': 1, 'jp': 5, 'xp': 10000},
             '5': {'ba': 2, 'jp': 7, 'xp': 13000},
             '6': {'ba': 2, 'jp': 7, 'xp': 26000},
             '7': {'ba': 2, 'jp': 7, 'xp': 36000},
             '8': {'ba': 3, 'jp': 7, 'xp': 46000},
             '9': {'ba': 3, 'jp': 7, 'xp': 56000}},
  'magic_items_description': 'Podem usar todos os tipos.',
  'name': 'Elfo Aventureiro',
  'parent_class_url': 'https://olddragon.com.br/classes/mago.json',
  'picture': 'https://public.olddragon.com.br/6uuaa1af4hcgwei7939ay4r1jsrc',
  'restrictions': {'races': ['elfo']},
  'thumb_picture': 'https://public.olddragon.com.br/7kr0k5jav5edcozc29742ocu185u',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/elfo-aventureiro.json',
  'weapons_description': 'Podem usar todas armas.'},
 {'abilities': [{'description': 'O sangue místico do Feiticeiro (Clérigo) '
                                'desperta e concede aleatoriamente a ele uma '
                                'magia arcana de 1º círculo. O Feiticeiro '
                                '(Clérigo) é capaz de lançar uma única magia '
                                'ao dia (sem qualquer tipo de memorização) e '
                                'deve seguir normalmente todas as regras de '
                                'conjuração de magias arcanas.',
                 'level': 1,
                 'level10': 'recebe uma magia extra de 4º círculo escolhida '
                            'aleatoriamente, passando a conjurar quatro magias '
                            'por dia. Além disso, pode trocar à sua escolha, '
                            'qualquer uma magia de 1º ou 2º círculos por uma '
                            'magia de 3º ou 4º círculos, na proporção de 1 '
                            'para 1, ou seja, uma magia de 2º círculo equivale '
                            'a duas de 1º círculo, três de 1º círculo a uma de '
                            '3º e assim sucessivamente.',
                 'level3': 'recebe uma magia extra de 2º círculo escolhida '
                           'aleatoriamente, passando a conjurar duas magias '
                           'por dia. Além disso, pode trocar à sua escolha '
                           'qualquer uma magia por uma magia de 2º círculo.',
                 'level6': 'recebe uma magia extra de 3º círculo escolhida '
                           'aleatoriamente, passando a conjurar três magias '
                           'por dia. Além disso, pode trocar à sua escolha, '
                           'qualquer uma magia de 2º círculo por uma magia de '
                           '3º círculo, ou duas magias de 1º círculo por uma '
                           'de 2º círculo.',
                 'name': 'Sangue Místico'},
                {'description': 'Um Feiticeiro (Clérigo) é capaz de lançar '
                                'magias divinas diariamente a partir do 1º '
                                'nível. Para prepará-las, o Feiticeiro '
                                '(Clérigo) deve rezar para o Panteão e pedir '
                                'que magias lhe sejam concedidas naquele dia, '
                                'respeitando os seus limites de nível e de '
                                'sabedoria.',
                 'level': 1,
                 'name': 'Magias Divinas'},
                {'description': 'O Feiticeiro (Clérigo) é capaz de invocar o '
                                'nome e o poder de sua divindade brandindo seu '
                                'símbolo sagrado, fazendo os mortos-vivos a '
                                'até 18 metros e que não passem em um teste de '
                                'moral no final da rodada, se contorcerem e '
                                'tentarem a todo custo fugir do Feiticeiro '
                                '(Clérigo).\n'
                                '\n'
                                '**Reduzir a Pó**: Se o morto-vivo não passar '
                                'no Teste de Moral e o resultado dos dados for '
                                'igual (tirando dois 4 nos dados, ou dois 5, '
                                'ou ainda dois 6) o morto-vivo não é apenas '
                                'afastado, mas também destruído e reduzido a '
                                'pó.\n'
                                '\n'
                                '**Alvo**: Todos os mortos-vivos num raio de '
                                'até 18 metros do Feiticeiro (Clérigo) são '
                                'afetados pelo Afastar Mortos-vivos. '
                                'Mortos-vivos bem-sucedidos no teste de moral '
                                'no final da rodada ficam imunes a um novo '
                                'Afastar Mortos-vivos proferidos por este '
                                'Feiticeiro (Clérigo), até este adquirir um '
                                'novo nível.',
                 'level': 1,
                 'level10': 'O Feiticeiro (Clérigo) recebe um bônus de +2 nos '
                            'seus testes de Afastar Mortos-Vivos e pode tentar '
                            'Afastar Mortos-Vivos três vezes ao dia.',
                 'level3': 'O Feiticeiro (Clérigo) recebe um bônus de +1 nos '
                           'seus testes de Afastar Mortos-Vivos e pode tentar '
                           'Afastar Mortos-Vivos duas vezes ao dia.',
                 'name': 'Afastar Mortos-Vivos'},
                {'description': 'Clérigos podem trocar uma magia previamente '
                                'memorizada por uma magia de Curar Ferimentos '
                                'de 1º círculo.',
                 'level': 1,
                 'level10': 'O Feiticeiro (Clérigo) evolui seu poder de Cura, '
                            'podendo trocar uma magia memorizada por Curar '
                            'Ferimentos de 5º círculo, que cura até 3d8 pontos '
                            'de vida.',
                 'level6': 'O Feiticeiro (Clérigo) evolui seu poder de Cura, '
                           'podendo trocar uma magia memorizada por Curar '
                           'Ferimentos de 3º círculo, que cura até 2d8 pontos '
                           'de vida.',
                 'name': 'Cura Milagrosa'},
                {'description': 'O Feiticeiro (Clérigo) de alto nível atinge '
                                'um grau superior de reconhecimento pelos seus '
                                'feitos, obtendo Reputação 1 em 1d6. O valor '
                                'de Reputação evolui em 1 até o máximo de 1-5 '
                                'em 1d6 no 15º nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Podem usar todas as armaduras.',
  'flavor': 'Não se conhece a origem dos Feiticeiros nem a causa da sua '
            'existência. A natureza do seu poder mágico é totalmente '
            'misterioso.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao.json',
              'page': None},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao-od2.json',
              'page': None}],
  'high_level_hp_bonus': 1,
  'hp': 8,
  'id': 'feiticeiro-clerigo',
  'levels': {'1': {'ba': 1, 'jp': 5},
             '10': {'ba': 7, 'jp': 11, 'xp': 112000},
             '11': {'ba': 7, 'jp': 11, 'xp': 220000},
             '12': {'ba': 7, 'jp': 11, 'xp': 340000},
             '13': {'ba': 9, 'jp': 13, 'xp': 460000},
             '14': {'ba': 9, 'jp': 13, 'xp': 580000},
             '15': {'ba': 9, 'jp': 13, 'xp': 700000},
             '2': {'ba': 1, 'jp': 5, 'xp': 3000},
             '3': {'ba': 1, 'jp': 5, 'xp': 6000},
             '4': {'ba': 3, 'jp': 7, 'xp': 10000},
             '5': {'ba': 3, 'jp': 7, 'xp': 13000},
             '6': {'ba': 3, 'jp': 7, 'xp': 26000},
             '7': {'ba': 5, 'jp': 9, 'xp': 36000},
             '8': {'ba': 5, 'jp': 9, 'xp': 46000},
             '9': {'ba': 5, 'jp': 9, 'xp': 56000}},
  'magic_items_description': 'O Feiticeiro (Clérigo) é capaz de usar todos os '
                             'tipos de itens mágicos desde que sejam ordeiros.',
  'name': 'Feiticeiro (Clérigo)',
  'parent_class_url': 'https://olddragon.com.br/classes/clerigo.json',
  'picture': 'https://public.olddragon.com.br/wyg9b6ywmk4txz6e04ws6f2dxokn',
  'restrictions': {},
  'thumb_picture': 'https://public.olddragon.com.br/byvamptl90vo5hnzq92hkuzvne43',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/feiticeiro-clerigo.json',
  'weapons_description': 'Só podem usar armas impactantes. Usar armas '
                         'cortantes ou perfurantes faz o Feiticeiro (Clérigo) '
                         'perder suas magias até realizar uma penitência para '
                         'restaurar o abalo na sua fé.'},
 {'abilities': [{'description': 'O sangue místico do Feiticeiro (Guerreiro) '
                                'desperta e concede aleatoriamente a ele uma '
                                'magia arcana de 1º círculo. O Feiticeiro '
                                '(Guerreiro) é capaz de lançar uma única magia '
                                'ao dia (sem qualquer tipo de memorização) e '
                                'deve seguir normalmente todas as regras de '
                                'conjuração de magias arcanas.',
                 'level': 1,
                 'level10': 'recebe uma magia extra de 4º círculo escolhida '
                            'aleatoriamente, passando a conjurar quatro magias '
                            'por dia. Além disso, pode trocar à sua escolha, '
                            'qualquer uma magia de 1º ou 2º círculos por uma '
                            'magia de 3º ou 4º círculos, na proporção de 1 '
                            'para 1, ou seja, uma magia de 2º círculo equivale '
                            'a duas de 1º círculo, três de 1º círculo a uma de '
                            '3º e assim sucessivamente.',
                 'level3': 'recebe uma magia extra de 2º círculo escolhida '
                           'aleatoriamente, passando a conjurar duas magias '
                           'por dia. Além disso, pode trocar à sua escolha '
                           'qualquer uma magia por uma magia de 2º círculo.',
                 'level6': 'recebe uma magia extra de 3º círculo escolhida '
                           'aleatoriamente, passando a conjurar três magias '
                           'por dia. Além disso, pode trocar à sua escolha, '
                           'qualquer uma magia de 2º círculo por uma magia de '
                           '3º círculo, ou duas magias de 1º círculo por uma '
                           'de 2º círculo.',
                 'name': 'Sangue Místico'},
                {'description': 'Um Feiticeiro (Guerreiro) pode, após receber '
                                'um ataque físico que o atinja e antes da '
                                'jogada de dano desse ataque, escolher '
                                'sacrificar seu escudo ou uma arma que esteja '
                                'portando para absorver todo o dano do ataque '
                                'recebido.\n'
                                '\n'
                                'Armas e Escudos usados em um aparar ficarão '
                                'inutilizados e danificados. Armas e Escudos '
                                'mágicos possuem uma chance de 1-2 em 1d6 de '
                                'se danificarem, reduzindo seus bônus (de '
                                'ataque/defesa) em 1 de modo que um escudo +3 '
                                'ao ser usado em um aparar, e se danificado, '
                                'passa ter como bônus de defesa +2 e assim '
                                'sucessivamente.\n'
                                '\n'
                                'Um item mágico que perder todos os bônus '
                                'estará permanentemente destruído. Apenas '
                                'ataques provenientes de inimigos grandes ou '
                                'menores poderão ser aparados.',
                 'level': 1,
                 'name': 'Aparar'},
                {'description': 'O Feiticeiro (Guerreiro) se torna Mestre em '
                                'uma arma à sua escolha, recebendo um bônus de '
                                '+1 no dano daquela arma.',
                 'level': 1,
                 'level10': 'O Feiticeiro (Guerreiro) evolui sua maestria para '
                            'todas as armas semelhantes àquelas que ele já '
                            'possui maestria, recebendo bônus em todas as '
                            'armas pertencentes a estes grupos.\n'
                            '\n'
                            'Os grupos de armas disponíveis são: cortantes, '
                            'perfurante, impactantes, disparos, hastes ou '
                            'arremesso. Todas as armas desses grupos melhoram '
                            'seus bônus de dano para +3.\n',
                 'level3': 'O Feiticeiro (Guerreiro) evolui sua maestria para '
                           'uma segunda arma à sua escolha e melhora o bônus '
                           'no dano de ambas as armas para +2.',
                 'name': 'Maestria em Arma'},
                {'description': 'Um Feiticeiro (Guerreiro) no 6º nível adquire '
                                'um segundo ataque, corpo a corpo ou à '
                                'distância, com uma mesma arma na qual possua '
                                'maestria.\n'
                                '\n'
                                'Este segundo ataque é realizado após o '
                                'primeiro ataque, logo em sequência, antes da '
                                'ação do próximo jogador na ordem da '
                                'iniciativa com a mesma BA usada no primeiro '
                                'ataque.',
                 'level': 6,
                 'name': 'Ataque Extra'},
                {'description': 'O Feiticeiro (Guerreiro) de alto nível atinge '
                                'um grau superior de reconhecimento pelos seus '
                                'feitos, obtendo Reputação 1 em 1d6. O valor '
                                'de Reputação evolui em 1 até o máximo de 1-5 '
                                'em 1d6 no 15º nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Pode usar todas as armaduras.',
  'flavor': 'Não se conhece a origem dos Feiticeiros nem a causa da sua '
            'existência. A natureza do seu poder mágico é totalmente '
            'misterioso.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao.json',
              'page': None},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao-od2.json',
              'page': None}],
  'high_level_hp_bonus': 2,
  'hp': 10,
  'id': 'feiticeiro-guerreiro',
  'levels': {'1': {'ba': 1, 'jp': 5},
             '10': {'ba': 10, 'jp': 11, 'xp': 112000},
             '11': {'ba': 11, 'jp': 13, 'xp': 220000},
             '12': {'ba': 12, 'jp': 13, 'xp': 340000},
             '13': {'ba': 13, 'jp': 14, 'xp': 460000},
             '14': {'ba': 14, 'jp': 14, 'xp': 580000},
             '15': {'ba': 15, 'jp': 16, 'xp': 700000},
             '2': {'ba': 2, 'jp': 5, 'xp': 3000},
             '3': {'ba': 3, 'jp': 6, 'xp': 6000},
             '4': {'ba': 4, 'jp': 6, 'xp': 10000},
             '5': {'ba': 5, 'jp': 8, 'xp': 13000},
             '6': {'ba': 6, 'jp': 8, 'xp': 26000},
             '7': {'ba': 7, 'jp': 10, 'xp': 36000},
             '8': {'ba': 8, 'jp': 10, 'xp': 46000},
             '9': {'ba': 9, 'jp': 11, 'xp': 56000}},
  'magic_items_description': 'Não pode usar cajados, varinhas e pergaminhos '
                             'mágicos com exceção dos pergaminhos de proteção.',
  'name': 'Feiticeiro (Guerreiro)',
  'parent_class_url': 'https://olddragon.com.br/classes/guerreiro.json',
  'picture': 'https://public.olddragon.com.br/do1kbc779qu23pd0qrqrisrrh09k',
  'restrictions': {},
  'thumb_picture': 'https://public.olddragon.com.br/vefzw7bu5d1fwmhom7ukt2u8mqax',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/feiticeiro-guerreiro.json',
  'weapons_description': 'Pode usar todas as armas.'},
 {'abilities': [{'description': 'O sangue místico do Feiticeiro (Ladrão) '
                                'desperta e concede aleatoriamente a ele uma '
                                'magia arcana de 1º círculo. O Feiticeiro '
                                '(Ladrão) é capaz de lançar uma única magia ao '
                                'dia (sem qualquer tipo de memorização) e deve '
                                'seguir normalmente todas as regras de '
                                'conjuração de magias arcanas.',
                 'level': 1,
                 'level10': 'recebe uma magia extra de 4º círculo escolhida '
                            'aleatoriamente, passando a conjurar quatro magias '
                            'por dia. Além disso, pode trocar à sua escolha, '
                            'qualquer uma magia de 1º ou 2º círculos por uma '
                            'magia de 3º ou 4º círculos, na proporção de 1 '
                            'para 1, ou seja, uma magia de 2º círculo equivale '
                            'a duas de 1º círculo, três de 1º círculo a uma de '
                            '3º e assim sucessivamente.',
                 'level3': 'recebe uma magia extra de 2º círculo escolhida '
                           'aleatoriamente, passando a conjurar duas magias '
                           'por dia. Além disso, pode trocar à sua escolha '
                           'qualquer uma magia por uma magia de 2º círculo.',
                 'level6': 'recebe uma magia extra de 3º círculo escolhida '
                           'aleatoriamente, passando a conjurar três magias '
                           'por dia. Além disso, pode trocar à sua escolha, '
                           'qualquer uma magia de 2º círculo por uma magia de '
                           '3º círculo, ou duas magias de 1º círculo por uma '
                           'de 2º círculo.',
                 'name': 'Sangue Místico'},
                {'description': 'O Feiticeiro (Ladrão) que ataca após ter se '
                                'aproximado do inimigo furtivamente, é capaz '
                                'de realizar um ataque muito fácil, causando '
                                'dano multiplicado por 2.',
                 'level': 1,
                 'level10': 'O dano do Ataque Furtivo é multiplicado por 4.',
                 'level6': 'O dano do Ataque Furtivo é multiplicado por 3.',
                 'name': 'Ataque Furtivo'},
                {'description': 'O Feiticeiro (Ladrão) consegue ouvir ruídos '
                                'como uma conversa do outro lado de uma porta '
                                'ou sons de monstros se aproximando. Para '
                                'isso, ele deve estar em um ambiente '
                                'silencioso, como em uma masmorra e fora de um '
                                'combate.\n'
                                '\n'
                                'O Feiticeiro (Ladrão) possui uma chance de '
                                '1-2 em 1d6 para conseguir ouvir ruídos.',
                 'level': 1,
                 'level10': 'A chance aumenta para 1-5 em 1d6.',
                 'level3': 'A chance aumenta para 1-3 em 1d6.',
                 'level6': 'A chance aumenta para 1-4 em 1d6.',
                 'name': 'Ouvir Ruídos'},
                {'description': 'Feiticeiros (Ladrões) possuem algumas '
                                'habilidades as quais representam seus '
                                'principais campos de atuação, começando com 2 '
                                'pontos em cada um dos cinco talentos e 2 '
                                'pontos adicionais para distribuir como '
                                'desejar.',
                 'level': 1,
                 'level10': 'Recebe 2 pontos para evoluir seus talentos.',
                 'level3': 'Recebe 2 pontos para evoluir seus talentos.',
                 'level6': 'Recebe 2 pontos para evoluir seus talentos.',
                 'name': 'Talentos de Ladrão'},
                {'description': 'O Feiticeiro (Ladrão) de alto nível atinge um '
                                'grau superior de reconhecimento pelos seus '
                                'feitos, obtendo Reputação 1 em 1d6. O valor '
                                'de Reputação evolui em 1 até o máximo de 1-5 '
                                'em 1d6 no 15º nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Apenas as leves. Escudos, Armaduras Média ou Pesadas, '
                        'impedem o uso das suas habilidades e protegem apenas '
                        'a metade da CA normal.',
  'flavor': 'Não se conhece a origem dos Feiticeiros nem a causa da sua '
            'existência. A natureza do seu poder mágico é totalmente '
            'misterioso.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao.json',
              'page': None},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao-od2.json',
              'page': None}],
  'high_level_hp_bonus': 1,
  'hp': 6,
  'id': 'feiticeiro-ladrao',
  'levels': {'1': {'ba': 1, 'jp': 5},
             '10': {'ba': 5, 'jp': 11, 'xp': 112000},
             '11': {'ba': 6, 'jp': 11, 'xp': 220000},
             '12': {'ba': 6, 'jp': 11, 'xp': 340000},
             '13': {'ba': 7, 'jp': 14, 'xp': 460000},
             '14': {'ba': 7, 'jp': 14, 'xp': 580000},
             '15': {'ba': 8, 'jp': 14, 'xp': 700000},
             '2': {'ba': 1, 'jp': 5, 'xp': 3000},
             '3': {'ba': 2, 'jp': 5, 'xp': 6000},
             '4': {'ba': 2, 'jp': 5, 'xp': 10000},
             '5': {'ba': 3, 'jp': 8, 'xp': 13000},
             '6': {'ba': 3, 'jp': 8, 'xp': 26000},
             '7': {'ba': 4, 'jp': 8, 'xp': 36000},
             '8': {'ba': 4, 'jp': 8, 'xp': 46000},
             '9': {'ba': 5, 'jp': 11, 'xp': 56000}},
  'magic_items_description': 'Não podem usar cajados, varinhas e pergaminhos '
                             'mágicos com exceção dos pergaminhos de proteção.',
  'name': 'Feiticeiro (Ladrão)',
  'parent_class_url': 'https://olddragon.com.br/classes/ladrao.json',
  'picture': 'https://public.olddragon.com.br/5c4j9lc1ggwo0ecf1ljj9vucxdjt',
  'restrictions': {},
  'thumb_picture': 'https://public.olddragon.com.br/9ekiikksy8197dald2550fkpbusw',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/feiticeiro-ladrao.json',
  'weapons_description': 'Apenas pequenas ou médias. Armas grandes geram '
                         'ataques difíceis para Feiticeiros (Ladrões).'},
 {'abilities': [{'description': 'Um Guerreiro pode, após receber um ataque '
                                'físico que o atinja e antes da jogada de dano '
                                'desse ataque, escolher sacrificar seu escudo '
                                'ou uma arma que esteja portando para absorver '
                                'todo o dano do ataque recebido.\n'
                                '\n'
                                'Armas e Escudos usados em um aparar ficarão '
                                'inutilizados e danificados. Armas e Escudos '
                                'mágicos possuem uma chance de 1-2 em 1d6 de '
                                'se danificarem, reduzindo seus bônus (de '
                                'ataque/defesa) em 1 de modo que um escudo +3 '
                                'ao ser usado em um aparar, e se danificado, '
                                'passa ter como bônus de defesa +2 e assim '
                                'sucessivamente.\n'
                                '\n'
                                'Um item mágico que perder todos os bônus '
                                'estará permanentemente destruído. Apenas '
                                'ataques provenientes de inimigos grandes ou '
                                'menores poderão ser aparados.',
                 'level': 1,
                 'name': 'Aparar'},
                {'description': 'O Guerreiro se torna Mestre em uma arma à sua '
                                'escolha, recebendo um bônus de +1 no dano '
                                'daquela arma.',
                 'level': 1,
                 'level10': 'O Guerreiro evolui sua maestria para todas as '
                            'armas semelhantes àquelas que ele já possui '
                            'maestria, recebendo bônus em todas as armas '
                            'pertencentes a estes grupos.\n'
                            '\n'
                            'Os grupos de armas disponíveis são: cortantes, '
                            'perfurante, impactantes, disparos, hastes ou '
                            'arremesso. Todas as armas desses grupos melhoram '
                            'seus bônus de dano para +3.\n',
                 'level3': 'O Guerreiro evolui sua maestria para uma segunda '
                           'arma à sua escolha e melhora o bônus no dano de '
                           'ambas as armas para +2.',
                 'name': 'Maestria em Arma'},
                {'description': 'Um Guerreiro no 6º nível adquire um segundo '
                                'ataque, corpo a corpo ou à distância, com uma '
                                'mesma arma na qual possua maestria.\n'
                                '\n'
                                'Este segundo ataque é realizado após o '
                                'primeiro ataque, logo em sequência, antes da '
                                'ação do próximo jogador na ordem da '
                                'iniciativa com a mesma BA usada no primeiro '
                                'ataque.',
                 'level': 6,
                 'name': 'Ataque Extra'},
                {'description': 'O Guerreiro de alto nível atinge um grau '
                                'superior de reconhecimento pelos seus feitos, '
                                'obtendo Reputação 1 em 1d6. O valor de '
                                'Reputação evolui em 1 até o máximo de 1-5 em '
                                '1d6 no 15º nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Pode usar todas as armaduras.',
  'flavor': 'Aventureiros especializados em combate, estão sempre na linha de '
            'frente e são mortais quando desembainham suas armas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 28},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'high_level_hp_bonus': 2,
  'hp': 10,
  'id': 'guerreiro',
  'levels': {'1': {'ba': 1, 'jp': 5},
             '10': {'ba': 10, 'jp': 11, 'xp': 100000},
             '11': {'ba': 11, 'jp': 13, 'xp': 200000},
             '12': {'ba': 12, 'jp': 13, 'xp': 300000},
             '13': {'ba': 13, 'jp': 14, 'xp': 400000},
             '14': {'ba': 14, 'jp': 14, 'xp': 500000},
             '15': {'ba': 15, 'jp': 16, 'xp': 600000},
             '2': {'ba': 2, 'jp': 5, 'xp': 2000},
             '3': {'ba': 3, 'jp': 6, 'xp': 4000},
             '4': {'ba': 4, 'jp': 6, 'xp': 7000},
             '5': {'ba': 5, 'jp': 8, 'xp': 10000},
             '6': {'ba': 6, 'jp': 8, 'xp': 20000},
             '7': {'ba': 7, 'jp': 10, 'xp': 30000},
             '8': {'ba': 8, 'jp': 10, 'xp': 40000},
             '9': {'ba': 9, 'jp': 11, 'xp': 50000}},
  'magic_items_description': 'Não pode usar cajados, varinhas e pergaminhos '
                             'mágicos com exceção dos pergaminhos de proteção.',
  'name': 'Guerreiro',
  'picture': 'https://public.olddragon.com.br/kzv3lg3nqiwlnjetiksiglh6c7qn',
  'restrictions': {},
  'thumb_picture': 'https://public.olddragon.com.br/f9ynvg64a9vucxgmbrgyxk3mrgoh',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/guerreiro.json',
  'weapons_description': 'Pode usar todas as armas.'},
 {'access': 'limited',
  'flavor': 'Combatente veterano, moldado pela guerra e pelas cicatrizes da '
            'batalha. Um verdadeiro mestre das armas no campo de batalha.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 60}],
  'id': 'guerreiro-sdg',
  'name': 'Guerreiro (Senhores da Guerra)',
  'parent_class_url': 'https://olddragon.com.br/classes/guerreiro.json',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/guerreiro-sdg.json'},
 {'abilities': [{'description': 'Halflings Aventureiros possuem algumas '
                                'habilidades as quais representam seus '
                                'principais campos de atuação, começando com 2 '
                                'pontos em cada um dos cinco talentos e 2 '
                                'pontos adicionais para distribuir como '
                                'desejar.',
                 'level': 1,
                 'level10': 'Recebe 2 pontos para evoluir seus talentos.',
                 'level3': 'Recebe 2 pontos para evoluir seus talentos.',
                 'level6': 'Recebe 2 pontos para evoluir seus talentos.',
                 'name': 'Talentos de Ladrão'},
                {'description': 'O Halfling Aventureiro mantém todas as '
                                'habilidades raciais recebidas por ser um '
                                'halfling e, devido ao intenso treinamento, '
                                'atinge um grau de especialização em uma arma '
                                'de arremesso à sua escolha, recebendo um '
                                'bônus de +2 no dano da arma escolhida. Esta '
                                'arma passa a ser tratada como sua arma '
                                'racial.',
                 'level': 1,
                 'name': 'Arma Racial'},
                {'description': 'O Halfling Aventureiro possui em suas veias o '
                                'sangue dos mais destemido dos halflings, '
                                'tornando-se imune a qualquer efeito de medo, '
                                'terror, horror ou semelhantes. Qualquer '
                                'tentativa de amedrontá-lo o tornará mais '
                                'corajoso, transformando seus testes de '
                                'atributo, jogada de proteção ou ataque em '
                                'testes fáceis.',
                 'level': 3,
                 'name': 'Valente'},
                {'description': 'Devido ao constante treinamento, o Halfling '
                                'Aventureiro evolui ainda mais a habilidade '
                                'natural de mira em arremessos. Deste ponto em '
                                'diante, qualquer ataque à distância realizado '
                                'com sua arma racial é considerado um ataque '
                                'muito fácil.',
                 'level': 6,
                 'name': 'No Alvo'},
                {'description': 'O Halfling Aventureiro adquire um segundo '
                                'arremesso por ataque quando empunhando sua '
                                'arma racial. Este segundo ataque é realizado '
                                'após o primeiro ataque, logo em sequência, '
                                'antes da ação do próximo jogador na ordem da '
                                'iniciativa com a mesma BA usada no primeiro '
                                'ataque.',
                 'level': 10,
                 'name': 'Arremesso Extra'},
                {'description': 'O Halfling Aventureiro de alto nível atinge '
                                'um grau superior de reconhecimento pelos seus '
                                'feitos, obtendo Reputação 1 em 1d6. O valor '
                                'de Reputação evolui em 1 até o máximo de 1-5 '
                                'em 1d6 no 15º nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Apenas as leves. Escudos, Armaduras Média ou Pesadas, '
                        'impedem o uso das suas habilidades e protegem apenas '
                        'a metade da CA normal.',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 31},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'high_level_hp_bonus': 1,
  'hp': 6,
  'id': 'halfling-aventureiro',
  'levels': {'1': {'ba': 1, 'jp': 5},
             '10': {'ba': 5, 'jp': 11, 'xp': 94000},
             '11': {'ba': 6, 'jp': 11, 'xp': 190000},
             '12': {'ba': 6, 'jp': 11, 'xp': 280000},
             '13': {'ba': 7, 'jp': 14, 'xp': 370000},
             '14': {'ba': 7, 'jp': 14, 'xp': 460000},
             '15': {'ba': 8, 'jp': 14, 'xp': 550000},
             '2': {'ba': 1, 'jp': 5, 'xp': 1500},
             '3': {'ba': 2, 'jp': 5, 'xp': 3000},
             '4': {'ba': 2, 'jp': 5, 'xp': 5500},
             '5': {'ba': 3, 'jp': 8, 'xp': 8500},
             '6': {'ba': 3, 'jp': 8, 'xp': 17000},
             '7': {'ba': 4, 'jp': 8, 'xp': 27000},
             '8': {'ba': 4, 'jp': 8, 'xp': 37000},
             '9': {'ba': 5, 'jp': 11, 'xp': 47000}},
  'magic_items_description': 'Não pode usar cajados, varinhas e pergaminhos '
                             'mágicos com exceção dos pergaminhos de proteção.',
  'name': 'Halfling Aventureiro',
  'parent_class_url': 'https://olddragon.com.br/classes/ladrao.json',
  'picture': 'https://public.olddragon.com.br/wcwnwc7kgt1uiubqsvv5ru5ugvg9',
  'restrictions': {'races': ['halfling']},
  'thumb_picture': 'https://public.olddragon.com.br/kt9dbsde2dbyrhji6pfqoxb9ssh0',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/halfling-aventureiro.json',
  'weapons_description': 'Apenas pequenas ou médias. Armas grandes geram '
                         'ataques difíceis para o Halfling Aventureiro.'},
 {'abilities': [{'description': 'Um Ilusionista é capaz de lançar magias '
                                'arcanas diariamente. Para memorizá-las, o '
                                'Ilusionista deve estudar seu livro de magias, '
                                'o grimório, e decidir quais magias serão '
                                'memorizadas naquele dia.\n'
                                '\n'
                                '**Grimório**: Livro no qual o Ilusionista '
                                'escreve sua coleção de magias, como um grande '
                                'livro de receitas arcanas. Sem ele, um '
                                'Ilusionista perde a capacidade de memorizar '
                                'novas magias. Por isso, um Ilusionista zeloso '
                                'guardará seu grimório como se fosse a própria '
                                'vida.\n'
                                '\n'
                                '**Magias Iniciais**: No 1º nível, o grimório '
                                'do Ilusionista contém três magias de 1º '
                                'círculo à escolha do Ilusionista e uma magia '
                                'escolhida aleatoriamente da sua lista de '
                                'magias de 1º círculo.\n'
                                '\n'
                                '**Novas Magias**: Um Ilusionista pode '
                                'acrescentar livremente novas magias ao seu '
                                'grimório copiando de outros grimórios ou de '
                                'pergaminhos.\n'
                                '\n'
                                '**Círculos Superiores**: Um Ilusionista pode '
                                'escrever no grimório magias de círculos acima '
                                'de sua capacidade, mas não pode memorizá-las '
                                'até atingir o nível necessário.',
                 'level': 1,
                 'name': 'Magias Arcanas'},
                {'description': 'Um Ilusionista é capaz de uma vez ao dia por '
                                'nível decifrar e ler inscrições mágicas em '
                                'qualquer lugar, mesmo que não entenda a '
                                'mensagem a qual elas querem passar.\n'
                                '\n'
                                'Esta habilidade não permite identificar as '
                                'propriedades mágicas de um item mágico, nem é '
                                'necessária para lançar magias escritas, mas '
                                'permitirá identificar qual magia está escrita '
                                'ali.',
                 'level': 1,
                 'name': 'Ler Magias'},
                {'description': 'Um Ilusionista é capaz de uma vez ao dia por '
                                'nível perceber em lugares, pessoas ou coisas '
                                'em uma área de até 9m + 3m por nível, a '
                                'presença de magia, desde que esteja '
                                'concentrado e procurando ativamente por '
                                'isso.\n'
                                '\n'
                                'O Ilusionista percebe uma tênue aura mágica '
                                'ao redor dos lugares, pessoas ou coisas '
                                'encantadas, mas não é capaz de identificar a '
                                'magia, o nível de poder do conjurador ou o '
                                'efeito presente no alvo.\n'
                                '\n'
                                'Um Ilusionista precisa se concentrar 1d8 '
                                'rodadas na área desejada para conseguir '
                                'detectar, caso haja, alguma presença mágica. '
                                'Esse tempo cai para 1d4 rodadas no 6º nível e '
                                'para 1 rodada no 10º nível.',
                 'level': 1,
                 'name': 'Detectar Magias'},
                {'description': 'O Ilusionista escreve em seu grimório Ilusão '
                                'e Som Ilusório, exclusivas para '
                                'Ilusionistas.\n'
                                '\n'
                                '- **Sem Memorizar**: Magias exclusivas não '
                                'precisam ser memorizadas para serem '
                                'conjuradas pelo Ilusionista.\n'
                                '- **Usos por dia**: Cada magia exclusiva do '
                                'Ilusionista em seu grimório pode ser usada '
                                'até uma vez ao dia, adicionalmente às magias '
                                'diárias do Ilusionista.\n'
                                '- **Usos Adicionais**: Caso outros usos sejam '
                                'realizados, a magia exclusiva consumirá o '
                                'espaço ocupado na memória do Ilusionista por '
                                'outra magia já previamente memorizada.\n'
                                '- **Jogada de Proteção**: Todas as Jogadas de '
                                'Proteção contra as magias exclusivas são '
                                'realizadas com um teste difícil.',
                 'level': 1,
                 'name': 'Magias Exclusivas'},
                {'description': 'O Ilusionista escreve esta magia exclusiva em '
                                'seu grimório.',
                 'level': 3,
                 'name': 'Ilusão Melhorada'},
                {'description': 'O Ilusionista escreve esta magia exclusiva em '
                                'seu grimório.',
                 'level': 6,
                 'name': 'Miragem'},
                {'description': 'O Ilusionista escreve esta magia exclusiva em '
                                'seu grimório.',
                 'level': 10,
                 'name': 'Ilusão Permanente'},
                {'description': 'O Ilusionista de alto nível atinge um grau '
                                'superior de reconhecimento pelos seus feitos, '
                                'obtendo Reputação 1 em 1d6. O valor de '
                                'Reputação evolui em 1 até o máximo de 1-5 em '
                                '1d6 no 15º nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Nenhuma. Usar escudos ou armaduras impede a '
                        'conjuração de magias e protegem apenas metade da CA '
                        'normal.',
  'flavor': 'O Ilusionista é um personagem ligado às artes das ilusões, o que '
            'significa ocultações, prestidigitação e manipulação da realidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 44},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'high_level_hp_bonus': 1,
  'hp': 4,
  'id': 'ilusionista',
  'levels': {'1': {'ba': 0, 'jp': 5},
             '10': {'ba': 3, 'jp': 10, 'xp': 112000},
             '11': {'ba': 4, 'jp': 10, 'xp': 220000},
             '12': {'ba': 4, 'jp': 10, 'xp': 340000},
             '13': {'ba': 4, 'jp': 10, 'xp': 460000},
             '14': {'ba': 5, 'jp': 13, 'xp': 580000},
             '15': {'ba': 5, 'jp': 13, 'xp': 700000},
             '2': {'ba': 1, 'jp': 5, 'xp': 3000},
             '3': {'ba': 1, 'jp': 5, 'xp': 6000},
             '4': {'ba': 1, 'jp': 5, 'xp': 10000},
             '5': {'ba': 2, 'jp': 7, 'xp': 13000},
             '6': {'ba': 2, 'jp': 7, 'xp': 26000},
             '7': {'ba': 2, 'jp': 7, 'xp': 36000},
             '8': {'ba': 3, 'jp': 7, 'xp': 46000},
             '9': {'ba': 3, 'jp': 7, 'xp': 56000}},
  'magic_items_description': 'Podem usar todos os tipos.',
  'name': 'Ilusionista',
  'parent_class_url': 'https://olddragon.com.br/classes/mago.json',
  'picture': 'https://public.olddragon.com.br/3yd24xxvdkmelsoyeluhksq31od8',
  'restrictions': {},
  'thumb_picture': 'https://public.olddragon.com.br/0fb2pex3pqakn1g43ppbdbrcj1i7',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/ilusionista.json',
  'weapons_description': 'Apenas pequenas. Armas grandes ou médias geram '
                         'ataques difíceis para Ilusionistas.'},
 {'abilities': [{'description': 'O Ladrão que ataca após ter se aproximado do '
                                'inimigo furtivamente, é capaz de realizar um '
                                'ataque muito fácil, causando dano '
                                'multiplicado por 2.',
                 'level': 1,
                 'level10': 'O dano do Ataque Furtivo é multiplicado por 4.',
                 'level6': 'O dano do Ataque Furtivo é multiplicado por 3.',
                 'name': 'Ataque Furtivo'},
                {'description': 'O Ladrão consegue ouvir ruídos como uma '
                                'conversa do outro lado de uma porta ou sons '
                                'de monstros se aproximando. Para isso, ele '
                                'deve estar em um ambiente silencioso, como em '
                                'uma masmorra e fora de um combate.\n'
                                '\n'
                                'O Ladrão possui uma chance de 1-2 em 1d6 para '
                                'conseguir ouvir ruídos.',
                 'level': 1,
                 'level10': 'A chance aumenta para 1-5 em 1d6.',
                 'level3': 'A chance aumenta para 1-3 em 1d6.',
                 'level6': 'A chance aumenta para 1-4 em 1d6.',
                 'name': 'Ouvir Ruídos'},
                {'description': 'Ladrões possuem algumas habilidades as quais '
                                'representam seus principais campos de '
                                'atuação, começando com 2 pontos em cada um '
                                'dos cinco talentos e 2 pontos adicionais para '
                                'distribuir como desejar.',
                 'level': 1,
                 'level10': 'Recebe 2 pontos para evoluir seus talentos.',
                 'level3': 'Recebe 2 pontos para evoluir seus talentos.',
                 'level6': 'Recebe 2 pontos para evoluir seus talentos.',
                 'name': 'Talentos de Ladrão'},
                {'description': 'O Ladrão de alto nível atinge um grau '
                                'superior de reconhecimento pelos seus feitos, '
                                'obtendo Reputação 1 em 1d6. O valor de '
                                'Reputação evolui em 1 até o máximo de 1-5 em '
                                '1d6 no 15º nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Apenas as leves. Escudos, Armaduras Média ou Pesadas, '
                        'impedem o uso das suas habilidades e protegem apenas '
                        'a metade da CA normal.',
  'flavor': 'Aventureiro táctico, perito em sobreviver em masmorras.\n'
            'Furtivo, traiçoeiro e fatal quando ataca suas vítimas '
            'sorrateiramente.\n',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 36},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'high_level_hp_bonus': 1,
  'hp': 6,
  'id': 'ladrao',
  'levels': {'1': {'ba': 1, 'jp': 5},
             '10': {'ba': 5, 'jp': 11, 'xp': 88000},
             '11': {'ba': 6, 'jp': 11, 'xp': 180000},
             '12': {'ba': 6, 'jp': 11, 'xp': 260000},
             '13': {'ba': 7, 'jp': 14, 'xp': 340000},
             '14': {'ba': 7, 'jp': 14, 'xp': 420000},
             '15': {'ba': 8, 'jp': 14, 'xp': 500000},
             '2': {'ba': 1, 'jp': 5, 'xp': 1000},
             '3': {'ba': 2, 'jp': 5, 'xp': 2000},
             '4': {'ba': 2, 'jp': 5, 'xp': 4000},
             '5': {'ba': 3, 'jp': 8, 'xp': 7000},
             '6': {'ba': 3, 'jp': 8, 'xp': 14000},
             '7': {'ba': 4, 'jp': 8, 'xp': 24000},
             '8': {'ba': 4, 'jp': 8, 'xp': 34000},
             '9': {'ba': 5, 'jp': 11, 'xp': 44000}},
  'magic_items_description': 'Não podem usar cajados, varinhas e pergaminhos '
                             'mágicos com exceção dos pergaminhos de proteção.',
  'name': 'Ladrão',
  'picture': 'https://public.olddragon.com.br/ijergxr5yi26ow9cwdqkfvog5tnc',
  'restrictions': {},
  'thumb_picture': 'https://public.olddragon.com.br/aeglx251om0x4cl5lf4940vvoi81',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/ladrao.json',
  'weapons_description': 'Apenas pequenas ou médias. Armas grandes geram '
                         'ataques difíceis para Ladrões.'},
 {'abilities': [{'description': 'Um Legionário pode, após receber um ataque '
                                'físico que o atinja e antes da jogada de dano '
                                'desse ataque, escolher sacrificar seu escudo '
                                'ou uma arma que esteja portando para absorver '
                                'todo o dano do ataque recebido.\n'
                                '\n'
                                'Armas e Escudos usados em um aparar ficarão '
                                'inutilizados e danificados. Armas e Escudos '
                                'mágicos possuem uma chance de 1-2 em 1d6 de '
                                'se danificarem, reduzindo seus bônus (de '
                                'ataque/defesa) em 1 de modo que um escudo +3 '
                                'ao ser usado em um aparar, e se danificado, '
                                'passa ter como bônus de defesa +2 e assim '
                                'sucessivamente.\n'
                                '\n'
                                'Um item mágico que perder todos os bônus '
                                'estará permanentemente destruído. Apenas '
                                'ataques provenientes de inimigos grandes ou '
                                'menores poderão ser aparados.',
                 'level': 1,
                 'name': 'Aparar'},
                {'description': 'O Legionário se torna Mestre em uma arma à '
                                'sua escolha, recebendo um bônus de +1 no dano '
                                'daquela arma.',
                 'level': 1,
                 'name': 'Maestria em Arma'},
                {'description': 'O Legionário recebe um equipamento e soldo de '
                                'acordo com a hierarquia que ocupa na legião. '
                                'Inicialmente ele recebe um soldo de 10 PP por '
                                'semana e um conjunto de equipamento composto '
                                'pela arma padrão da legião, escudo e armadura '
                                'de couro. Enquanto estiver usando este '
                                'equipamento, o Legionário recebe um bônus de '
                                '+1 nos danos causados pela arma padrão e '
                                'outro bônus de +1 no seu CA.',
                 'level': 1,
                 'level10': '**Comandante**: O Legionário passa a receber um '
                            'soldo de 100 PP por semana e seu equipamento '
                            'evolui para arma padrão, escudo e armadura '
                            'completa. Enquanto estiver usando este '
                            'equipamento, o Legionário recebe um bônus de +4 '
                            'nos danos causados pela espada curta e outro '
                            'bônus de +1 no seu CA.',
                 'level3': '**Sargento**: O Legionário passa a receber um '
                           'soldo de 30 PP por semana e seu equipamento evolui '
                           'para arma da legião, escudo e cota de malhas. '
                           'Enquanto estiver usando este equipamento, o '
                           'Legionário recebe um bônus de +2 nos danos '
                           'causados pela arma padrão e outro bônus de +1 no '
                           'seu CA.',
                 'level6': '**Capitão**: O Legionário passa a receber um soldo '
                           'de 60 PP por semana e seu equipamento evolui para '
                           'arma da legião, escudo e armadura de placas. '
                           'Enquanto estiver usando este equipamento, o '
                           'Legionário recebe um bônus de +3 nos danos '
                           'causados pela arma padrão e outro bônus de +1 no '
                           'seu CA.',
                 'name': 'Soldado'},
                {'description': 'O Legionário de alto nível atinge um grau '
                                'superior de reconhecimento pelos seus feitos, '
                                'obtendo Reputação 1 em 1d6. O valor de '
                                'Reputação evolui em 1 até o máximo de 1-5 em '
                                '1d6 no 15º nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Pode usar todas as armaduras.',
  'flavor': 'Legionários são conhecidos por serem soldados bem treinados e '
            'organizados. Porém, sempre devem estar disponíveis para servir a '
            'sua legião 1d4 meses por ano. Dependendo de onde se encontrem, '
            'Legionários são respeitados, temidos ou ainda odiados.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao.json',
              'page': None},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao-od2.json',
              'page': None}],
  'high_level_hp_bonus': 2,
  'hp': 10,
  'id': 'legionario',
  'levels': {'1': {'ba': 1, 'jp': 5},
             '10': {'ba': 10, 'jp': 11, 'xp': 106000},
             '11': {'ba': 11, 'jp': 13, 'xp': 210000},
             '12': {'ba': 12, 'jp': 13, 'xp': 320000},
             '13': {'ba': 13, 'jp': 14, 'xp': 430000},
             '14': {'ba': 14, 'jp': 14, 'xp': 540000},
             '15': {'ba': 15, 'jp': 16, 'xp': 650000},
             '2': {'ba': 2, 'jp': 5, 'xp': 2500},
             '3': {'ba': 3, 'jp': 6, 'xp': 5000},
             '4': {'ba': 4, 'jp': 6, 'xp': 8500},
             '5': {'ba': 5, 'jp': 8, 'xp': 11500},
             '6': {'ba': 6, 'jp': 8, 'xp': 23000},
             '7': {'ba': 7, 'jp': 10, 'xp': 33000},
             '8': {'ba': 8, 'jp': 10, 'xp': 43000},
             '9': {'ba': 9, 'jp': 11, 'xp': 53000}},
  'magic_items_description': 'Não pode usar cajados, varinhas e pergaminhos '
                             'mágicos com exceção dos pergaminhos de proteção.',
  'name': 'Legionário',
  'parent_class_url': 'https://olddragon.com.br/classes/guerreiro.json',
  'picture': 'https://public.olddragon.com.br/ii04tsw6ntyh82w7ceso0o2k3lq1',
  'restrictions': {},
  'thumb_picture': 'https://public.olddragon.com.br/2k956wcg9hbdwrm1bqe900nu45e5',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/legionario.json',
  'weapons_description': 'Pode usar todas as armas.'},
 {'abilities': [{'description': 'Um Mago é capaz de lançar magias arcanas '
                                'diariamente. Para memorizá-las, o Mago deve '
                                'estudar seu livro de magias, o grimório, e '
                                'decidir quais magias serão memorizadas '
                                'naquele dia.\n'
                                '\n'
                                '**Grimório**: Livro no qual o Mago escreve '
                                'sua coleção de magias, como um grande livro '
                                'de receitas arcanas. Sem ele, um Mago perde a '
                                'capacidade de memorizar novas magias. Por '
                                'isso, um Mago zeloso guardará seu grimório '
                                'como se fosse a própria vida.\n'
                                '\n'
                                '**Magias Iniciais**: No 1º nível, o grimório '
                                'do Mago contém três magias de 1º círculo à '
                                'escolha do Mago e uma magia escolhida '
                                'aleatoriamente da sua lista de magias de 1º '
                                'círculo.\n'
                                '\n'
                                '**Novas Magias**: Um Mago pode acrescentar '
                                'livremente novas magias ao seu grimório '
                                'copiando de outros grimórios ou de '
                                'pergaminhos.\n'
                                '\n'
                                '**Círculos Superiores**: Um Mago pode '
                                'escrever no grimório magias de círculos acima '
                                'de sua capacidade, mas não pode memorizá-las '
                                'até atingir o nível necessário.',
                 'level': 1,
                 'name': 'Magias Arcanas'},
                {'description': 'Um Mago é capaz de uma vez ao dia por nível '
                                'decifrar e ler inscrições mágicas em qualquer '
                                'lugar, mesmo que não entenda a mensagem a '
                                'qual elas querem passar.\n'
                                '\n'
                                'Esta habilidade não permite identificar as '
                                'propriedades mágicas de um item mágico, nem é '
                                'necessária para lançar magias escritas, mas '
                                'permitirá identificar qual magia está escrita '
                                'ali.',
                 'level': 1,
                 'name': 'Ler Magias'},
                {'description': 'Um Mago é capaz de uma vez ao dia por nível '
                                'perceber em lugares, pessoas ou coisas em uma '
                                'área de até 9m + 3m por nível, a presença de '
                                'magia, desde que esteja concentrado e '
                                'procurando ativamente por isso.\n'
                                '\n'
                                'O Mago percebe uma tênue aura mágica ao redor '
                                'dos lugares, pessoas ou coisas encantadas, '
                                'mas não é capaz de identificar a magia, o '
                                'nível de poder do conjurador ou o efeito '
                                'presente no alvo.\n'
                                '\n'
                                'Um Mago precisa se concentrar 1d8 rodadas na '
                                'área desejada para conseguir detectar, caso '
                                'haja, alguma presença mágica. Esse tempo cai '
                                'para 1d4 rodadas no 6º nível e para 1 rodada '
                                'no 10º nível.',
                 'level': 1,
                 'name': 'Detectar Magias'},
                {'description': 'O Mago de alto nível atinge um grau superior '
                                'de reconhecimento pelos seus feitos, obtendo '
                                'Reputação 1 em 1d6. O valor de Reputação '
                                'evolui em 1 até o máximo de 1-5 em 1d6 no 15º '
                                'nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Nenhuma. Usar escudos ou armaduras impede a '
                        'conjuração de magias e protegem apenas metade da CA '
                        'normal.',
  'flavor': 'Aventureiro estudioso, especializado nas artes arcanas, dedicado '
            'a conjurar magias escritas em grimórios e pergaminhos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 42},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'high_level_hp_bonus': 1,
  'hp': 4,
  'id': 'mago',
  'levels': {'1': {'ba': 0, 'jp': 5},
             '10': {'ba': 3, 'jp': 10, 'xp': 106000},
             '11': {'ba': 4, 'jp': 10, 'xp': 210000},
             '12': {'ba': 4, 'jp': 10, 'xp': 320000},
             '13': {'ba': 4, 'jp': 10, 'xp': 430000},
             '14': {'ba': 5, 'jp': 13, 'xp': 540000},
             '15': {'ba': 5, 'jp': 13, 'xp': 650000},
             '2': {'ba': 1, 'jp': 5, 'xp': 2500},
             '3': {'ba': 1, 'jp': 5, 'xp': 5000},
             '4': {'ba': 1, 'jp': 5, 'xp': 8500},
             '5': {'ba': 2, 'jp': 7, 'xp': 11500},
             '6': {'ba': 2, 'jp': 7, 'xp': 23000},
             '7': {'ba': 2, 'jp': 7, 'xp': 33000},
             '8': {'ba': 3, 'jp': 7, 'xp': 43000},
             '9': {'ba': 3, 'jp': 7, 'xp': 53000}},
  'magic_items_description': 'Podem usar todos os tipos.',
  'name': 'Mago',
  'picture': 'https://public.olddragon.com.br/3cgvufvhw1ujj1pn3vzbycum4d5b',
  'restrictions': {},
  'thumb_picture': 'https://public.olddragon.com.br/fhye142ch11c1erobcpj64wx4ajx',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/mago.json',
  'weapons_description': 'Apenas pequenas. Armas grandes ou médias geram '
                         'ataques difíceis para Magos.'},
 {'abilities': [{'description': 'Um Necromante é capaz de lançar magias '
                                'arcanas diariamente. Para memorizá-las, o '
                                'Necromante deve estudar seu livro de magias, '
                                'o grimório, e decidir quais magias serão '
                                'memorizadas naquele dia.\n'
                                '\n'
                                '**Grimório**: Livro no qual o Necromante '
                                'escreve sua coleção de magias, como um grande '
                                'livro de receitas arcanas. Sem ele, um '
                                'Necromante perde a capacidade de memorizar '
                                'novas magias. Por isso, um Necromante zeloso '
                                'guardará seu grimório como se fosse a própria '
                                'vida.\n'
                                '\n'
                                '**Magias Iniciais**: No 1º nível, o grimório '
                                'do Necromante contém três magias de 1º '
                                'círculo à escolha do Mago e uma magia '
                                'escolhida aleatoriamente da sua lista de '
                                'magias de 1º círculo.\n'
                                '\n'
                                '**Novas Magias**: Um Necromante pode '
                                'acrescentar livremente novas magias ao seu '
                                'grimório copiando de outros grimórios ou de '
                                'pergaminhos.\n'
                                '\n'
                                '**Círculos Superiores**: Um Necromante pode '
                                'escrever no grimório magias de círculos acima '
                                'de sua capacidade, mas não pode memorizá-las '
                                'até atingir o nível necessário.',
                 'level': 1,
                 'name': 'Magias Arcanas'},
                {'description': 'Um Necromante é capaz de uma vez ao dia por '
                                'nível decifrar e ler inscrições mágicas em '
                                'qualquer lugar, mesmo que não entenda a '
                                'mensagem a qual elas querem passar.\n'
                                '\n'
                                'Esta habilidade não permite identificar as '
                                'propriedades mágicas de um item mágico, nem é '
                                'necessária para lançar magias escritas, mas '
                                'permitirá identificar qual magia está escrita '
                                'ali.',
                 'level': 1,
                 'name': 'Ler Magias'},
                {'description': 'Um Necromante é capaz de uma vez ao dia por '
                                'nível perceber em lugares, pessoas ou coisas '
                                'em uma área de até 9m + 3m por nível, a '
                                'presença de magia, desde que esteja '
                                'concentrado e procurando ativamente por '
                                'isso.\n'
                                '\n'
                                'O Necromante percebe uma tênue aura mágica ao '
                                'redor dos lugares, pessoas ou coisas '
                                'encantadas, mas não é capaz de identificar a '
                                'magia, o nível de poder do conjurador ou o '
                                'efeito presente no alvo.\n'
                                '\n'
                                'Um Necromante precisa se concentrar 1d8 '
                                'rodadas na área desejada para conseguir '
                                'detectar, caso haja, alguma presença mágica. '
                                'Esse tempo cai para 1d4 rodadas no 6º nível e '
                                'para 1 rodada no 10º nível.',
                 'level': 1,
                 'name': 'Detectar Magias'},
                {'description': 'O Necromante escreve em seu grimório, Toque '
                                'Sombrio e Aterrorizar, exclusivas para '
                                'Necromantes.\n'
                                '\n'
                                '- **Sem Memorizar**: Magias exclusivas não '
                                'precisam ser memorizadas para serem '
                                'conjuradas pelo Necromante.\n'
                                '- **Usos por dia**: Cada magia exclusiva do '
                                'Necromante em seu grimório pode ser usada até '
                                'uma vez ao dia, adicionalmente às magias '
                                'diárias do Necromante.\n'
                                '- **Usos Adicionais**: Caso outros usos sejam '
                                'realizados, a magia exclusiva consumirá o '
                                'espaço ocupado na memória do Necromante por '
                                'outra magia já previamente memorizada.\n'
                                '- **Jogada de Proteção**: Todas as Jogadas de '
                                'Proteção contra as magias exclusivas são '
                                'realizadas com um teste difícil.',
                 'level': 1,
                 'name': 'Magias Exclusivas'},
                {'description': 'O Necromante escreve esta magia exclusiva em '
                                'seu grimório.',
                 'level': 3,
                 'name': 'Criar Mortos-Vivos'},
                {'description': 'O Necromante escreve esta magia exclusiva em '
                                'seu grimório.',
                 'level': 6,
                 'name': 'Drenar Vida'},
                {'description': 'O Necromante escreve esta magia exclusiva em '
                                'seu grimório.',
                 'level': 10,
                 'name': 'Magia da Morte'},
                {'description': 'O Necromante de alto nível atinge um grau '
                                'superior de reconhecimento pelos seus feitos, '
                                'obtendo Reputação 1 em 1d6. O valor de '
                                'Reputação evolui em 1 até o máximo de 1-5 em '
                                '1d6 no 15º nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Nenhuma. Usar escudos ou armaduras impede a '
                        'conjuração de magias e protegem apenas metade da CA '
                        'normal.',
  'flavor': 'O Necromante é um estudioso dos fatos obscuros os quais cercam a '
            'vida e a morte, estudando as energias místicas que interferem nos '
            'efeitos destes conceitos sobre os seres vivos ou não.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 45},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'high_level_hp_bonus': 1,
  'hp': 4,
  'id': 'necromante',
  'levels': {'1': {'ba': 0, 'jp': 5},
             '10': {'ba': 3, 'jp': 10, 'xp': 112000},
             '11': {'ba': 4, 'jp': 10, 'xp': 220000},
             '12': {'ba': 4, 'jp': 10, 'xp': 340000},
             '13': {'ba': 4, 'jp': 10, 'xp': 460000},
             '14': {'ba': 5, 'jp': 13, 'xp': 580000},
             '15': {'ba': 5, 'jp': 13, 'xp': 700000},
             '2': {'ba': 1, 'jp': 5, 'xp': 3000},
             '3': {'ba': 1, 'jp': 5, 'xp': 6000},
             '4': {'ba': 1, 'jp': 5, 'xp': 10000},
             '5': {'ba': 2, 'jp': 7, 'xp': 13000},
             '6': {'ba': 2, 'jp': 7, 'xp': 26000},
             '7': {'ba': 2, 'jp': 7, 'xp': 36000},
             '8': {'ba': 3, 'jp': 7, 'xp': 46000},
             '9': {'ba': 3, 'jp': 7, 'xp': 56000}},
  'magic_items_description': 'Podem usar todos os tipos.',
  'name': 'Necromante',
  'parent_class_url': 'https://olddragon.com.br/classes/mago.json',
  'picture': 'https://public.olddragon.com.br/go86lqiw2v8g2wn3qxy6ygsyfmyj',
  'restrictions': {},
  'thumb_picture': 'https://public.olddragon.com.br/i9qg12obpj9ayzb1dweqdniv2mfp',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/necromante.json',
  'weapons_description': 'Apenas pequenas. Armas grandes ou médias geram '
                         'ataques difíceis para Necromantes.'},
 {'access': 'limited',
  'flavor': 'Servo devoto, guia espiritual e voz da fé em tempos de guerra e '
            'desespero.\n',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 62}],
  'id': 'padre-sdg',
  'name': 'Padre (Senhores da Guerra)',
  'parent_class_url': 'https://olddragon.com.br/classes/clerigo.json',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/padre-sdg.json'},
 {'abilities': [{'description': 'Um Paladino pode, após receber um ataque '
                                'físico que o atinja e antes da jogada de dano '
                                'desse ataque, escolher sacrificar seu escudo '
                                'ou uma arma que esteja portando para absorver '
                                'todo o dano do ataque recebido.\n'
                                '\n'
                                'Armas e Escudos usados em um aparar ficarão '
                                'inutilizados e danificados. Armas e Escudos '
                                'mágicos possuem uma chance de 1-2 em 1d6 de '
                                'se danificarem, reduzindo seus bônus (de '
                                'ataque/defesa) em 1 de modo que um escudo +3 '
                                'ao ser usado em um aparar, e se danificado, '
                                'passa ter como bônus de defesa +2 e assim '
                                'sucessivamente.\n'
                                '\n'
                                'Um item mágico que perder todos os bônus '
                                'estará permanentemente destruído. Apenas '
                                'ataques provenientes de inimigos grandes ou '
                                'menores poderão ser aparados.',
                 'level': 1,
                 'name': 'Aparar'},
                {'description': 'O Paladino se torna Mestre em uma arma à sua '
                                'escolha, recebendo um bônus de +1 no dano '
                                'daquela arma.\n',
                 'level': 1,
                 'name': 'Maestria em Arma'},
                {'description': 'O Paladino adquire imunidade a qualquer tipo '
                                'de doença, seja mundana ou mágica. Danos e '
                                'outros efeitos não causam nenhum efeito, como '
                                'se não fosse contagiado.',
                 'level': 1,
                 'name': 'Imunidade a Doenças'},
                {'description': 'O Paladino adquire a habilidade de curar pela '
                                'simples imposição das suas mãos, até uma vez '
                                'por dia.\n'
                                '\n'
                                'O alvo tocado cura 1 ponto de vida por nível '
                                'do Paladino. Essa habilidade não cura doenças '
                                'e nem regenera membros amputados, mas pode '
                                'ser usada para prestar auxílio a um alvo que '
                                'esteja agonizando.',
                 'level': 3,
                 'name': 'Cura pelas Mãos'},
                {'description': 'O Paladino adquire a habilidade de criar uma '
                                'barreira permanente de proteção ao seu redor, '
                                'exatamente como o efeito da magia Proteção '
                                'contra Alinhamento, a qual o protege contra '
                                'criaturas caóticas.',
                 'level': 6,
                 'name': 'Aura de Proteção'},
                {'description': 'O Paladino, ao derrotar um inimigo caótico de '
                                'grande poder, adquire uma espada mágica a '
                                'qual, após ser consagrada à sua causa, se '
                                'converte em uma Espada Sagrada com ímpeto e '
                                'poderes contra o caos.\n'
                                '\n'
                                'Uma Espada Sagrada mantém todos os bônus '
                                'normais de uma espada mágica, mas passa a ser '
                                'imbuída também com um bônus especial de +5 '
                                'nos danos e nos ataques contra criaturas '
                                'caóticas.',
                 'level': 10,
                 'name': 'Espada Sagrada'},
                {'description': 'O Paladino de alto nível atinge um grau '
                                'superior de reconhecimento pelos seus feitos, '
                                'obtendo Reputação 1 em 1d6. O valor de '
                                'Reputação evolui em 1 até o máximo de 1-5 em '
                                '1d6 no 15º nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Pode usar todas as armaduras.',
  'flavor': 'O Paladino é um herói cavalheiresco, errante, destemido e de '
            'caráter inquestionável que segue o caminho da ordem da verdade e '
            'da lei, estando sempre disposto a proteger os fracos e a lutar '
            'pela erradicação do caos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 31},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'high_level_hp_bonus': 2,
  'hp': 10,
  'id': 'paladino',
  'levels': {'1': {'ba': 1, 'jp': 5},
             '10': {'ba': 10, 'jp': 11, 'xp': 106000},
             '11': {'ba': 11, 'jp': 13, 'xp': 210000},
             '12': {'ba': 12, 'jp': 13, 'xp': 320000},
             '13': {'ba': 13, 'jp': 14, 'xp': 430000},
             '14': {'ba': 14, 'jp': 14, 'xp': 540000},
             '15': {'ba': 15, 'jp': 16, 'xp': 650000},
             '2': {'ba': 2, 'jp': 5, 'xp': 2500},
             '3': {'ba': 3, 'jp': 6, 'xp': 5000},
             '4': {'ba': 4, 'jp': 6, 'xp': 8500},
             '5': {'ba': 5, 'jp': 8, 'xp': 11500},
             '6': {'ba': 6, 'jp': 8, 'xp': 23000},
             '7': {'ba': 7, 'jp': 10, 'xp': 33000},
             '8': {'ba': 8, 'jp': 10, 'xp': 43000},
             '9': {'ba': 9, 'jp': 11, 'xp': 53000}},
  'magic_items_description': 'Não pode usar cajados, varinhas e pergaminhos '
                             'mágicos com exceção dos pergaminhos de proteção.',
  'name': 'Paladino',
  'parent_class_url': 'https://olddragon.com.br/classes/guerreiro.json',
  'picture': 'https://public.olddragon.com.br/hz9vbu4tkmhrw0de0qltw1tiz437',
  'restrictions': {'alignments': ['ordeiro']},
  'thumb_picture': 'https://public.olddragon.com.br/q01bwc9d4bsude883a9kx7uq7j5j',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/paladino.json',
  'weapons_description': 'Pode usar todas as armas.'},
 {'access': 'limited',
  'flavor': 'Cavaleiro sagrado, defensor da fé e da ordem, guiado por um '
            'código de honra inquebrantável.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 60}],
  'id': 'paladino-sdg',
  'name': 'Paladino (Senhores da Guerra)',
  'parent_class_url': 'https://olddragon.com.br/classes/guerreiro.json',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/paladino-sdg.json'},
 {'abilities': [{'description': 'Apesar de incapaz de conjurar magias de cura, '
                                'graças a sua experiência acumulada em cuidar '
                                'de enfermos, um Proscrito desenvolve a '
                                'habilidade de curar ferimentos como um '
                                'curandeiro ou médico, aumentando para 2 a '
                                'cura natural de um alvo ou para 1d4+1 para '
                                'alvos que permaneçam em repouso. A Cura '
                                'Natural do Proscrito pode ser usada para '
                                'evitar a morte de personagens agonizando.',
                 'level': 1,
                 'name': 'Cura Natural'},
                {'description': 'Abandonando as orações, estudos e meditações, '
                                'o Proscrito usa seu tempo livre para melhorar '
                                'seu treinamento em combate. Além da '
                                'possibilidade de usar qualquer arma ou '
                                'armadura, um Proscrito recebe um bônus de +1 '
                                'na sua BA em relação a BA de um Clérigo '
                                'padrão.',
                 'level': 3,
                 'name': 'Treinamento em Combate'},
                {'description': 'Mesmo sem o poder da sua fé para afastar ou '
                                'destruir mortos-vivos, o Proscrito é capaz '
                                'de, uma vez por dia, afetar negativamente os '
                                'mortos-vivos, forçando um teste de moral aos '
                                'mortos-vivos presentes. O Proscrito não faz '
                                'isso para afastá-los, e sim para transformar '
                                'todos os seus ataques em ataques difíceis. '
                                'Mortos-vivos que passarem no teste de moral '
                                'não serão afetados.',
                 'level': 6,
                 'name': 'Afetar Mortos-Vivos'},
                {'description': 'Sua antiga divindade, por pena ou premiando a '
                                'persistência, concede ao Proscrito a '
                                'habilidade de conjurar magias divi- nas de 1º '
                                'círculo de acordo com a tabela padrão de '
                                'Clérigo (3.2) correspondente ao seu nível. '
                                'Esta conjuração segue todas as regras normais '
                                'para conjuração de magias divinas.',
                 'level': 10,
                 'name': 'Misticismo'},
                {'description': 'O Poscrito de alto nível atinge um grau '
                                'superior de reconhecimento pelos seus feitos, '
                                'obtendo Reputação 1 em 1d6. O valor de '
                                'Reputação evolui em 1 até o máximo de 1-5 em '
                                '1d6 no 15º nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Pode usar todas as armaduras.',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 27},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'high_level_hp_bonus': 1,
  'hp': 8,
  'id': 'proscrito',
  'levels': {'1': {'ba': 1, 'jp': 5},
             '10': {'ba': 8, 'jp': 11, 'xp': 100000},
             '11': {'ba': 8, 'jp': 11, 'xp': 200000},
             '12': {'ba': 8, 'jp': 11, 'xp': 300000},
             '13': {'ba': 10, 'jp': 13, 'xp': 400000},
             '14': {'ba': 10, 'jp': 13, 'xp': 500000},
             '15': {'ba': 10, 'jp': 13, 'xp': 600000},
             '2': {'ba': 1, 'jp': 5, 'xp': 2000},
             '3': {'ba': 2, 'jp': 5, 'xp': 4000},
             '4': {'ba': 4, 'jp': 7, 'xp': 7000},
             '5': {'ba': 4, 'jp': 7, 'xp': 10000},
             '6': {'ba': 4, 'jp': 7, 'xp': 20000},
             '7': {'ba': 6, 'jp': 9, 'xp': 30000},
             '8': {'ba': 6, 'jp': 9, 'xp': 40000},
             '9': {'ba': 6, 'jp': 9, 'xp': 50000}},
  'magic_items_description': 'O Poscrito é capaz de usar todos os tipos de '
                             'itens mágicos.',
  'name': 'Proscrito',
  'parent_class_url': 'https://olddragon.com.br/classes/clerigo.json',
  'picture': 'https://public.olddragon.com.br/9gkmvbdwr132pzsml4lbmz18s9a3',
  'restrictions': {},
  'thumb_picture': 'https://public.olddragon.com.br/n4smhyqbiihmlzfd2ex4pnrhoayj',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/proscrito.json',
  'weapons_description': 'Pode usar todas as armas.'},
 {'abilities': [{'description': 'Rangers possuem algumas habilidades as quais '
                                'representam seus principais campos de '
                                'atuação, começando com 2 pontos em cada um '
                                'dos cinco talentos e 2 pontos adicionais para '
                                'distribuir como desejar.',
                 'level': 1,
                 'level10': 'Recebe 2 pontos para evoluir seus talentos.',
                 'level3': 'Recebe 2 pontos para evoluir seus talentos.',
                 'level6': 'Recebe 2 pontos para evoluir seus talentos.',
                 'name': 'Talentos de Ladrão'},
                {'description': 'O Ranger não pode acumular mais tesouros do '
                                'que é capaz de carregar. Em contrapartida, os '
                                'Rangers jamais se perdem enquanto estiverem '
                                'nos ermos.',
                 'level': 1,
                 'name': 'Restrição'},
                {'description': 'Assumindo seu papel de guardião de uma região '
                                'dos ermos, adota um inimigo que assola sua '
                                'região para combatê-lo.\n'
                                '\n'
                                'Inimigos Mortais podem ser escolhidos dentre '
                                'Orcs, Goblins, Homens Lagartos, Trolls ou '
                                'Gigantes. Contra estas criaturas, todo ataque '
                                'é considerado um **ataque fácil** e todo '
                                '**teste de reação** possui uma penalizador de '
                                '-2',
                 'level': 1,
                 'name': 'Inimigo Mortal'},
                {'description': 'O Ranger passa a poder usar armas grandes e '
                                'escudos sem penalidades, mas continua '
                                'limitado a usar Armaduras Leves.',
                 'level': 3,
                 'name': 'Combativo'},
                {'description': 'O Ranger está sempre alerta e prevenido '
                                'quando estiver nos ermos. Nestas condições, '
                                'um Ranger só pode ser surpreendido com um '
                                'resultado de 1 em 1d6, e todo acampamento '
                                'criado por um Ranger nos ermos sempre será do '
                                'tipo seguro.',
                 'level': 6,
                 'name': 'Previdência'},
                {'description': 'Uma criatura dos ermos adota o Ranger como '
                                'aliado e realiza favores, como atacar, '
                                'vigiar, enviar mensagens ou algo semelhante e '
                                'não ofensivo a si próprio (como, por exemplo, '
                                'se matar).\n'
                                '\n'
                                'Se um companheiro animal morrer, há 1-4 '
                                'chances em 1d6 de um novo companheiro surgir '
                                'a cada novo nível adquirido pelo Ranger.',
                 'level': 10,
                 'name': 'Companheiro Animal'},
                {'description': 'O Ranger de alto nível atinge um grau '
                                'superior de reconhecimento pelos seus feitos, '
                                'obtendo Reputação 1 em 1d6. O valor de '
                                'Reputação evolui em 1 até o máximo de 1-5 em '
                                '1d6 no 15º nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Apenas as leves. Escudos, Armaduras Média ou Pesadas, '
                        'impedem o uso das suas habilidades e protegem apenas '
                        'a metade da CA normal.',
  'flavor': 'O Ranger é um personagem oriundo dos ermos dedicado a patrulhar '
            'uma área silvestre, natural ou selvagem protegendo-a de bestas e '
            'monstros.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 40},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'high_level_hp_bonus': 1,
  'hp': 6,
  'id': 'ranger',
  'levels': {'1': {'ba': 1, 'jp': 5},
             '10': {'ba': 5, 'jp': 11, 'xp': 94000},
             '11': {'ba': 6, 'jp': 11, 'xp': 190000},
             '12': {'ba': 6, 'jp': 11, 'xp': 280000},
             '13': {'ba': 7, 'jp': 14, 'xp': 370000},
             '14': {'ba': 7, 'jp': 14, 'xp': 460000},
             '15': {'ba': 8, 'jp': 14, 'xp': 550000},
             '2': {'ba': 1, 'jp': 5, 'xp': 1500},
             '3': {'ba': 2, 'jp': 5, 'xp': 3000},
             '4': {'ba': 2, 'jp': 5, 'xp': 5500},
             '5': {'ba': 3, 'jp': 8, 'xp': 8500},
             '6': {'ba': 3, 'jp': 8, 'xp': 17000},
             '7': {'ba': 4, 'jp': 8, 'xp': 27000},
             '8': {'ba': 4, 'jp': 8, 'xp': 37000},
             '9': {'ba': 5, 'jp': 11, 'xp': 47000}},
  'magic_items_description': 'Não podem usar cajados, varinhas e pergaminhos '
                             'mágicos com exceção dos pergaminhos de proteção.',
  'name': 'Ranger',
  'parent_class_url': 'https://olddragon.com.br/classes/ladrao.json',
  'picture': 'https://public.olddragon.com.br/3f8ykld6rygj8h6hsk8nvs7rsr8g',
  'restrictions': {},
  'thumb_picture': 'https://public.olddragon.com.br/hg9sqmr3tsoptmb33j58hxmoq03l',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/ranger.json',
  'weapons_description': 'Apenas pequenas ou médias. Armas grandes geram '
                         'ataques difíceis para o Ranger.'},
 {'access': 'limited',
  'flavor': 'Guardião dos ermos e rastreador silencioso, caçador de homens e '
            'feras nos campos e florestas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 60}],
  'id': 'ranger-sdg',
  'name': 'Ranger (Senhores da Guerra)',
  'parent_class_url': 'https://olddragon.com.br/classes/ladrao.json',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/ranger-sdg.json'},
 {'abilities': [{'description': 'Um Xamã é capaz de lançar magias divinas '
                                'diariamente a partir do 1º nível. Para '
                                'prepará-las, o Xamã deve rezar para o Panteão '
                                'e pedir que magias lhe sejam concedidas '
                                'naquele dia, respeitando os seus limites de '
                                'nível e de sabedoria.',
                 'level': 1,
                 'name': 'Magias Divinas'},
                {'description': 'O Xamã seleciona um animal ou criatura para '
                                'representar sua divindade junto a sua tribo. '
                                'Sempre que este símbolo divino estiver '
                                'presente, o Xamã pode fazer seus seguidores '
                                'realizarem ataques fáceis durante um combate, '
                                'enquanto for capaz de proferir canções '
                                'sagradas e ritmadas, colocando todos em '
                                'transe.',
                 'level': 1,
                 'name': 'Animal Sagrado'},
                {'description': 'Assim como um Clérigo, o Xamã recebe a '
                                'habilidade de trocar uma das suas magias '
                                'preparadas previamente por uma magia de Curar '
                                'Ferimentos de 1º círculo a qual cura 1d8 '
                                'pontos de vida.',
                 'level': 3,
                 'name': 'Cura Totêmica'},
                {'description': 'O Xamã pode iniciar uma cantoria sagrada e '
                                'ritmada para estimular um dos seus seguidores '
                                'a entrar em fúria. Um alvo aliado, enquanto o '
                                'Xamã for capaz de manter a cantoria '
                                'ritualística, sobe o dado de dano da sua arma '
                                'para o dado imediatamente superior (d4 para '
                                'd6, d6 para d8 etc.) e realiza todos seus '
                                'ataques como ataques muito fáceis. Em '
                                'contrapartida, o furioso passa a ser '
                                'considerado um alvo fácil para todos os '
                                'ataques que receber.',
                 'level': 6,
                 'name': 'Fúria'},
                {'description': 'O Xamã invoca o poder de sua divindade '
                                'natural representada em uma força da '
                                'natureza, recebendo a habilidade de trocar '
                                'uma das suas magias preparadas de 5º círculo '
                                'pela magia de 7º círculo Controlar o Clima.\n'
                                '\n'
                                'Um Xamã é capaz de conjurar esta magia mesmo '
                                'se ainda não tiver acesso às magias de 7º '
                                'círculo.',
                 'level': 10,
                 'name': 'Fúria da Natureza'},
                {'description': 'O Xamã de alto nível atinge um grau superior '
                                'de reconhecimento pelos seus feitos, obtendo '
                                'Reputação 1 em 1d6. O valor de Reputação '
                                'evolui em 1 até o máximo de 1-5 em 1d6 no 15º '
                                'nível.',
                 'level': 11,
                 'name': 'Reputação'}],
  'access': 'complete',
  'armors_description': 'Não pode usar nenhuma armadura metálica.',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 26},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'high_level_hp_bonus': 1,
  'hp': 8,
  'id': 'xama',
  'levels': {'1': {'ba': 1, 'jp': 5},
             '10': {'ba': 7, 'jp': 11, 'xp': 100000},
             '11': {'ba': 7, 'jp': 11, 'xp': 200000},
             '12': {'ba': 7, 'jp': 11, 'xp': 300000},
             '13': {'ba': 9, 'jp': 13, 'xp': 400000},
             '14': {'ba': 9, 'jp': 13, 'xp': 500000},
             '15': {'ba': 9, 'jp': 13, 'xp': 600000},
             '2': {'ba': 1, 'jp': 5, 'xp': 2000},
             '3': {'ba': 1, 'jp': 5, 'xp': 4000},
             '4': {'ba': 3, 'jp': 7, 'xp': 7000},
             '5': {'ba': 3, 'jp': 7, 'xp': 10000},
             '6': {'ba': 3, 'jp': 7, 'xp': 20000},
             '7': {'ba': 5, 'jp': 9, 'xp': 30000},
             '8': {'ba': 5, 'jp': 9, 'xp': 40000},
             '9': {'ba': 5, 'jp': 9, 'xp': 50000}},
  'magic_items_description': 'Pode usar qualquer item mágico.',
  'name': 'Xamã',
  'parent_class_url': 'https://olddragon.com.br/classes/clerigo.json',
  'picture': 'https://public.olddragon.com.br/az3qgnjurj2qsopojgwrh8snyy7p',
  'restrictions': {'alignments': ['neutro']},
  'thumb_picture': 'https://public.olddragon.com.br/sbw60mpbkr6t0d9ntl6aq96vghd5',
  'type': 'CharacterClass',
  'url': 'https://olddragon.com.br/classes/xama.json',
  'weapons_description': 'Não pode usar nenhuma arma metálica.'}]



def buscar(
    lista: list,
    termo_busca: str,
    chave: str = 'name'
) -> dict:
    """Realiza uma busca por um termo exato

    Args:
        lista (list): qual a lista que se deseja buscar
        termo_busca (str): qual o termo a ser buscado
        chave (str, optional): qual a chave que se deseja buscar. Defaults to 'name'.

    Returns:
        dict: o dicionário do item buscado na lista
    """
    return next((
        item for item in lista
        if item.get(chave, '').lower() == termo_busca.lower()
    ), None)


def filtrar(
    lista: list,
    termo_busca: str,
    chave: str = 'name'
) -> GeneratorExit:
    """Filtra a lista para o termo escolhido com relação à chave escolhida ('name') por padrão

        Args:
            lista (list): qual a lista que se deseja filtrar
            termo_busca (str): qual o termo a ser buscado
            chave (str, optional): qual a chave que se deseja buscar. Defaults to 'name'.

        Returns:
            generator: um gerador com o resultado
    """
    return (
        item for item in lista
        if termo_busca.lower() in item.get(chave).lower()
    )


def filtrar_alcance(
    lista: list,
    chave: str,
    maior_que: int | float = float('-inf'),
    menor_que: int | float = float('inf'),
):
    """Filtra por alcance de valores, por exemplo: monstros com XP entre 100 e 300

    Args:
        lista (list): A lista a ser buscada
        chave (str): A chave para a consulta ('xp' no exemplo acima)
        maior_que (int | float, optional): O valor que a busca deve ser maior ou igual (100 no exemplo). Defaults to float('-inf').
        menor_que (int | float, optional): O valor que a busca deve ser menor ou igual (300 no exemplo). Defaults to float('inf').

    Returns:
        generator: um gerador com o resultado
    """
    pre_filtro = (
        item for item in lista
        if isinstance(item.get(chave), (int, float)) or
        (isinstance(item.get(chave), str) and item.get(chave).isdigit())
    )
    return (
        item for item in pre_filtro
        if maior_que <= float(item.get(chave)) <= menor_que
    )


def filtrar_por_exclusao(
    lista: list,
    termo_excluir: str,
    chave: str = 'name'
):
    """Filtra por itens que não coincidam com o termo

    Args:
        lista (list): A lista a ser buscada
        termo_excluir (str): O termo que não deve estar na lista
        chave (str, optional): Qual a chave a ser buscada na lista. Defaults to 'name'.

    Returns:
        generator: O gerador com o resultado
    """
    return (
        item for item in lista
        if termo_excluir.lower() not in item.get(chave).lower()
    )


def filtrar_livro_basico(lista: list):
    """Filtra por somente itens que existam nos três livros básicos

    Args:
        lista (list): qual a lista que deve ser filtrada

    Returns:
        generator: O gerador como resultado
    """
    return (
        item for item in lista
        if any('livros/lb' in fonte.get('digital_item_url', '') for fonte in item.get('fontes', []))
    )



def _checar_conversao(texto: str):
    try:
        int(texto)
        return True
    except (ValueError, TypeError):
        return False
    
def converter_para_numero(texto: str):
    if _checar_conversao(texto):
        return int(texto)
    return texto

def converter_para_texto(numero: int | None):
    if numero == None or numero == 0:
        return ''
    return f'{numero}' if numero < 0 else f'+{numero}'



from RPG import Dado
from typing import Literal

from ...od2.data import DATA
from ...od2.helpers import jogada_ataque


TIPOS_EQUIPAMENTOS = Literal[
    'armadura',
    'recipiente',
    'veículo',
    'item',
    'escudo',
    'arma'
]


def buscar_equipamento(busca: str, chave: str = 'id'):
    """Busca um equipamento na api
    Args:
        busca (str): o id do equipamento a ser buscado. Pode ser também o nome
        chave (str, optional): se a busca é por id ou nome. Defaults to 'id'.

    Returns:
        dict: o dicionário com os dados do equipamento
    """

    resultado = [item for item in DATA.EQUIPAMENTOS if item[chave] == busca]
    return resultado[0]


def filtrar_equipamento(tipo: str):
    dicionario = {
        'armadura': 'armor', 
        'recipiente': 'container', 
        'veículo': 'vehicle', 
        'item': 'misc', 
        'escudo': 'shield', 
        'arma': 'weapon'
    }
    return [item for item in DATA.EQUIPAMENTOS if item['concept'] == dicionario[tipo]]


class Equipamento:
    def __init__(self, data: dict):
        self.data = data

    def __str__(self):
        return f'{self.__class__.__name__}(data["id"]="{self.data['id']}")'

    def __repr__(self):
        return f'{self.__class__.__name__}(data["id"]="{self.data['id']}")'


    #! Propriedades
    @property
    def peso(self):
        gramas = self.data['weight_in_grams']
        load = self.data['weight_in_load']

        gramas = gramas / 1000 if gramas else 0
        load = load if load else 0

        return gramas + load
        
    @property
    def preco(self):
        return self.data['cost']


class Arma(Equipamento):
    def __init__(self, data: str, ataque: int = 0):
        super().__init__(data)
        self.ataque = ataque

    #! Propriedades
    @property
    def propriedades(self):
        lista = self.data['description'].split(', ')
        lista[-1] = lista[-1].replace('.', '') # retira o ponto final do último item
        return lista
    
    @property
    def dano(self):
        return self.data['damage']
    
    #! Métodos
    def rolar_dano(self):
        if self.dano:
            converte_dado = [int(i) for i in self.dano.split('d')]
            return Dado(*converte_dado)


class Armadura(Equipamento):
    def __init__(self, data: str, equipada: bool = False):
        super().__init__(data)
        self.equipada = equipada

    #! Propriedades
    @property
    def ca(self):
        return self.data['bonus_ca']
    

class Escudo(Armadura):
    def __init__(self, data: str, equipado: bool = False):
        super().__init__(data, equipado)
